package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.30.1 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.30.1) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`MP`!````)"````````!``````````&"A````
M`````````$``.``(`$``%@`5``8````$````0`````````!``````````$``
M````````P`$```````#``0````````@``````````P````0``````@``````
M```"``````````(````````:`````````!H``````````0`````````!````
M!0```````````````````````````````````&R0````````;)``````````
M``$```````$````&````@)L```````"`FP$``````(";`0``````^`0`````
M``!0%0```````````0```````@````8```"0FP```````)";`0``````D)L!
M``````#@`0```````.`!````````"`````````!0Y71D!````%B*````````
M6(H```````!8B@```````/0`````````]``````````$`````````%'E=&0&
M`````````````````````````````````````````````````````````!``
M````````4N5T9`0```"`FP```````(";`0``````@)L!``````"`!```````
M`(`$`````````0`````````O;&EB+VQD+6UU<VPM86%R8V@V-"YS;RXQ````
M`````!$```!.````!`````@````A$!``!<`$@"@`$`6`AD"$@B$`!`D`!(F(
M@!A!N@0""$X```!/````4P```%@```!9````8````&$```!B`````````&0`
M``!E`````````&8```!G````:@```````````````:\TZ&I_FGSJT^\.SMY'
M+6_%WQ\NQ9NVN(WQ#M1DU'QV5#R4(?_D#MEQ6!SZH6Q@PN4_++(!BV]"^M>'
MXD?&`5COEWF[XY)\5<,\TF>OS&:(!W#30T75[#-BV^T5C"7,?ZF<F^"G`@IJ
M&IY0O]I7&Z/@^TD``````````````````````````````````````P`'`#@:
M`````````````````````````P`2``"@`0`````````````````,````$@``
M``````````````````````#:`0``$@`````````````````````````4````
M$0```````````````````````````@``$0````````````````````````!\
M`0``$@`````````````````````````;````$@``````````````````````
M``"Y`0``$@`````````````````````````C````$@``````````````````
M```````J````$@`````````````````````````-`@``$@``````````````
M``````````#%`0``$@`````````````````````````S````(```````````
M``````````````!!`P``(0````````````````````````!+````$@``````
M``````````````````!1````$@````````````````````````!8````$@``
M```````````````````````.`P``$@````````````````````````#_`@``
M$@````````````````````````"2`@``$@````````````````````````!?
M````$@`````````````````````````S`@``$@``````````````````````
M``!F````$@````````````````````````#'`@``$@``````````````````
M``````!M````$@````````````````````````!U````$@``````````````
M``````````"P`@``$@````````````````````````!]````$@``````````
M``````````````"#````$@````````````````````````",````(```````
M``````````````````#X`@``$@````````````````````````"H````$@``
M``````````````````````"M````$@`````````````````````````>`@``
M$0````````````````````````#.`@``$@````````````````````````!@
M`@``$@````````````````````````"T````$@``````````````````````
M``!2`@``$@````````````````````````!E`P``$@``````````````````
M``````!``P``$0````````````````````````"$`@``$@``````````````
M```````````M`P``$@````````````````````````!"`P``$0``````````
M``````````````"[````$@`````````````````````````E`P``$@``````
M``````````````````#$````$0````````````````````````"*`0``$@``
M``````````````````````#6````(@````````````````````````#E````
M(`````````````````````````#[````$@````````````````````````#P
M`@``$@````````````````````````!P`@``$@``````````````````````
M`````0``$@`````````````````````````&`0``(```````````````````
M``````"[`@``$@`````````````````````````@`0``$@``````````````
M``````````"J`0``$@`````````````````````````E`0``$@``````````
M``````````````"@`@``$@````````````````````````"9`0``$@``````
M```````````````````K`0``$@`````````````````````````\`0``$@``
M```````````````````````N`@``$@````````````````````````!^````
M$@`````````````````````````_`@``$@````````````````````````!Y
M`@``$@`````````````````````````>`P``$@``````````````````````
M``!"`0``$@`````````````````````````6`P``$@``````````````````
M``````!6`0``$@`````````````````````````I`@``$@``````````````
M``````````#H`0``$@````````````````````````!=`0``$@``````````
M``````````````!D`0``$@`````````````````````````_`P``(0``````
M``````````````````!U`0``$@````````````````````````!E!```$``3
M`-"P`0`````````````````Z`P``$@`)`%`>````````U`$```````#Z`0``
M$@`*``!-````````!`````````"G`P``$@`)`$`N````````W`4```````!U
M!```$@`)`&PW````````9`````````"$`P``$@`)`'0H````````!```````
M```9!```$@`'`#@:````````!`````````#*`P``$@`)`!PT````````4`,`
M```````?!```$``3`'B@`0````````````````!-!```$@`)`'@H````````
MT`$````````"!```$``3`'B@`0````````````````"5`P``$@`)`(PM````
M````M`````````"T`P``$@`)`+@F````````.`````````"\`P``$@`)`!0M
M````````6`````````#@`P``$@`)`/Q)````````<`$```````#U`P``$@`)
M`$@J````````(``````````.!```$``3`-"P`0````````````````!P!```
M$``3`-"P`0````````````````!*`P``$@`)`$`@````````*``````````M
M!```$@`)`&@J````````!`$```````#K`P``$0`2`'"@`0``````"```````
M``!&!```$``2`'B@`0`````````````````'!```$@`)`"0@````````````
M```````6!```$@`)`*!)````````7`````````!3`P``$@`)`&PM````````
M(`````````!N`P``$@`)`$0G````````,`$```````!:!```$@`)`&Q+````
M````E`$```````!D!```$``3`-"P`0`````````````````Y!```$@`)`&PK
M````````J`$`````````;&EB<&5R;"YS;P!O<&5N9&ER`'-T9&5R<@!R96%L
M;&]C`&%C8V5S<P!S;G!R:6YT9@!?7V1E<F5G:7-T97)?9G)A;65?:6YF;P!L
M<V5E:P!G971P:60`<W1R8VUP`&UE;7-E=`!U;FQI;FL`;65M;6]V90!S=')N
M8VUP`&QS=&%T`&-L;W-E9&ER`%])5$U?9&5R96=I<W1E<E1-0VQO;F5486)L
M90!O<&5N`'-T<G-T<@!S=')C:'(`<F5A9&QI;FL`7U]S=&%C:U]C:&M?9W5A
M<F0`7U]C>&%?9FEN86QI>F4`7U]R96=I<W1E<E]F<F%M95]I;F9O`&5X:70`
M8VQO<V4`7TE435]R96=I<W1E<E1-0VQO;F5486)L90!R96%D`')M9&ER`%]?
M97)R;F]?;&]C871I;VX`;6MD:7(`<'1H<F5A9%]G971S<&5C:69I8P!M96UC
M<'D`<W1R;&5N`%]?<W1A8VM?8VAK7V9A:6P`9V5T=6ED`%!E<FQ?<WES7W1E
M<FT`4&5R;%]S>7-?:6YI=#,`4&5R;%]A=&9O<FM?;&]C:P!P97)L7V-O;G-T
M<G5C=`!097)L7V=E=%]S=@!097)L7V-R;V%K7VYO8V]N=&5X=`!097)L7V%V
M7W-H:69T`%!E<FQ?<W9?,G!V7V9L86=S`%]F:6YI`%!,7V1O7W5N9'5M<`!0
M97)L7VYE=UA37V9L86=S`%!,7W1H<E]K97D`<&5R;%]F<F5E`%!E<FQ?;6=?
M<V5T`%!E<FQ?871F;W)K7W5N;&]C:P!097)L7W-V7W-E='!V`%!E<FQ?9W9?
M9F5T8VAP=@!P97)L7W)U;@!097)L7VYE=UA3`'!E<FQ?9&5S=')U8W0`4&5R
M;%]A=E]F971C:`!B;V]T7T1Y;F%,;V%D97(`<&5R;%]P87)S90!097)L7W-A
M9F5S>7-M86QL;V,`<&5R;%]A;&QO8P!L:6)C+FUU<VPM86%R8V@V-"YS;RXQ
M`&9P<FEN=&8`<W1R9'5P`'!T:')E861?871F;W)K`')E861D:7(`<W!R:6YT
M9@!S=')T;VL`<W1R;F-P>0!?7VQI8F-?<W1A<G1?;6%I;@!?7U]E;G9I<F]N
M`%]S=&%R=%]C`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`'!A<E]C=7)R
M96YT7V5X96-?<')O8P!P87)?8W5R<F5N=%]E>&5C`'!A<E]S971U<%]L:6)P
M871H`'!A<E]M:W1M<&1I<@!X<U]I;FET`'!A<E]E;G9?8VQE86X`6%-?26YT
M97)N86QS7U!!4E]"3T]4`'-H85]U<&1A=&4`;7E?<&%R7W!L`'!A<E]B87-E
M;F%M90!?7V)S<U]S=&%R=`!?7V5N9%]?`'-H85]I;FET`%]?8G-S7W-T87)T
M7U\`<&%R7V1I<FYA;64`<&%R7VEN:71?96YV`%]E9&%T80!P87)?9FEN9'!R
M;V<`<VAA7V9I;F%L`%]?8G-S7V5N9%]?`%]E;F0`<&%R7V-L96%N=7``+W5S
M<B]L:6(O<&5R;#4O8V]R95]P97)L+T-/4D4``(";`0```````P0````````\
M(0```````(B;`0```````P0```````#4(````````("?`0```````P0`````
M``!0'@```````)B?`0```````P0`````````30```````+"?`0```````P0`
M```````X&@````````"@`0```````P0`````````H`$``````!"@`0``````
M`P0````````030```````!B@`0```````P0````````[30```````"B@`0``
M`````P0````````530```````#"@`0```````P0````````53@```````#B@
M`0```````P0````````@30```````$"@`0```````P0````````G3@``````
M`$B@`0```````P0````````H30```````%B@`0```````P0````````L30``
M`````&"@`0```````P0````````Q30```````'"@`0```````P0```````#+
M3P```````(B?`0```````00```4``````````````)"?`0```````00```8`
M`````````````*"?`0```````00```X``````````````*B?`0```````00`
M`!\``````````````+B?`0```````00``",``````````````,"?`0``````
M`00``"P``````````````,B?`0```````00``"\``````````````-"?`0``
M`````00``#$``````````````-B?`0```````00``#(``````````````."?
M`0```````00``#<``````````````.B?`0```````00``#P`````````````
M`/"?`0```````00``#T``````````````/B?`0```````00``$(`````````
M`````(B=`0```````@0```,``````````````)"=`0```````@0```0`````
M`````````)B=`0```````@0```<``````````````*"=`0```````@0```@`
M`````````````*B=`0```````@0```D``````````````+"=`0```````@0`
M``H``````````````+B=`0```````@0```L``````````````,"=`0``````
M`@0```P``````````````,B=`0```````@0```T``````````````-"=`0``
M`````@0```X``````````````-B=`0```````@0``!```````````````."=
M`0```````@0``!$``````````````.B=`0```````@0``!(`````````````
M`/"=`0```````@0``!,``````````````/B=`0```````@0``!0`````````
M``````">`0```````@0``!4```````````````B>`0```````@0``!8`````
M`````````!">`0```````@0``!<``````````````!B>`0```````@0``!@`
M`````````````"">`0```````@0``!D``````````````"B>`0```````@0`
M`!H``````````````#">`0```````@0``!L``````````````#B>`0``````
M`@0``!P``````````````$">`0```````@0``!T``````````````$B>`0``
M`````@0``!X``````````````%">`0```````@0``"```````````````%B>
M`0```````@0``"$``````````````&">`0```````@0``"(`````````````
M`&B>`0```````@0``"0``````````````'">`0```````@0``"4`````````
M`````'B>`0```````@0``"8``````````````(">`0```````@0``"<`````
M`````````(B>`0```````@0``"@``````````````)">`0```````@0``"H`
M`````````````)B>`0```````@0``"L``````````````*">`0```````@0`
M`"T``````````````*B>`0```````@0``"X``````````````+">`0``````
M`@0``#```````````````+B>`0```````@0``#$``````````````,">`0``
M`````@0``#(``````````````,B>`0```````@0``#,``````````````-">
M`0```````@0``#0``````````````-B>`0```````@0``#4`````````````
M`.">`0```````@0``#8``````````````.B>`0```````@0``#@`````````
M`````/">`0```````@0``#D``````````````/B>`0```````@0``#H`````
M``````````"?`0```````@0``#L```````````````B?`0```````@0``#X`
M`````````````!"?`0```````@0``#\``````````````!B?`0```````@0`
M`$```````````````""?`0```````@0``$$``````````````"B?`0``````
M`@0``$,``````````````#"?`0```````@0``$0``````````````#B?`0``
M`````@0``$4``````````````$"?`0```````@0``$8``````````````$B?
M`0```````@0``$<``````````````%"?`0```````@0``$@`````````````
M`%B?`0```````@0``$D``````````````&"?`0```````@0``$H`````````
M`````&B?`0```````@0``$L``````````````'"?`0```````@0``$T`````
M`````````/U[OZG]`P"1_7O!J,`#7]8``````````/![OZG0``"0$<)&^1`"
M-I$@`A_6'R`#U1\@`]4?(`/5T```D!'&1OD0(C:1(`(?UM```)`1RD;Y$$(V
MD2`"'];0``"0$<Y&^1!B-I$@`A_6T```D!'21OD0@C:1(`(?UM```)`1UD;Y
M$*(VD2`"'];0``"0$=I&^1#"-I$@`A_6T```D!'>1OD0XC:1(`(?UM```)`1
MXD;Y$`(WD2`"'];0``"0$>9&^1`B-Y$@`A_6T```D!'J1OD00C>1(`(?UM``
M`)`1[D;Y$&(WD2`"'];0``"0$?)&^1""-Y$@`A_6T```D!'V1OD0HC>1(`(?
MUM```)`1^D;Y$,(WD2`"'];0``"0$?Y&^1#B-Y$@`A_6T```D!$"1_D0`CB1
M(`(?UM```)`1!D?Y$"(XD2`"'];0``"0$0I'^1!".)$@`A_6T```D!$.1_D0
M8CB1(`(?UM```)`1$D?Y$((XD2`"'];0``"0$19'^1"B.)$@`A_6T```D!$:
M1_D0PCB1(`(?UM```)`1'D?Y$.(XD2`"'];0``"0$2)'^1`".9$@`A_6T```
MD!$F1_D0(CF1(`(?UM```)`1*D?Y$$(YD2`"'];0``"0$2Y'^1!B.9$@`A_6
MT```D!$R1_D0@CF1(`(?UM```)`1-D?Y$*(YD2`"'];0``"0$3I'^1#".9$@
M`A_6T```D!$^1_D0XCF1(`(?UM```)`10D?Y$`(ZD2`"'];0``"0$49'^1`B
M.I$@`A_6T```D!%*1_D00CJ1(`(?UM```)`13D?Y$&(ZD2`"'];0``"0$5)'
M^1"".I$@`A_6T```D!%61_D0HCJ1(`(?UM```)`16D?Y$,(ZD2`"'];0``"0
M$5Y'^1#B.I$@`A_6T```D!%B1_D0`CN1(`(?UM```)`19D?Y$"([D2`"'];0
M``"0$6I'^1!".Y$@`A_6T```D!%N1_D08CN1(`(?UM```)`1<D?Y$(([D2`"
M'];0``"0$79'^1"B.Y$@`A_6T```D!%Z1_D0PCN1(`(?UM```)`1?D?Y$.([
MD2`"'];0``"0$8)'^1`"/)$@`A_6T```D!&&1_D0(CR1(`(?UM```)`1BD?Y
M$$(\D2`"'];0``"0$8Y'^1!B/)$@`A_6T```D!&21_D0@CR1(`(?UM```)`1
MED?Y$*(\D2`"'];0``"0$9I'^1#"/)$@`A_6T```D!&>1_D0XCR1(`(?UM``
M`)`1HD?Y$`(]D2`"'];0``"0$:9'^1`B/9$@`A_6T```D!&J1_D00CV1(`(?
MUM```)`1KD?Y$&(]D2`"'];0``"0$;)'^1""/9$@`A_6T```D!&V1_D0HCV1
M(`(?UM```)`1ND?Y$,(]D2`"'];]>[NI_0,`D?-3`:G3``"PU```D/43`/GB
MAP.IXN,`D>$#`9'@3P"YX#,!D9'__Y?"``"0P```D$+\1_D`^$?YX0,"JB__
M_Y?```"0`,A'^0``0#F``0`U8O__EV+"`I%`#`#Y8```M2``@%*-__^7I/__
MEX#>1_D``$"YP?__EQ_$*#F4WD?Y@`)`N;W__Y<!:%(Y(0`?,@%H$CF``D"Y
MN/__EP%H4CDA```R`6@2.>!/0+D`%``1`'Q]DXG__Y?E(T#YXP,`JF'"`I'B
M3T"YY`"`DJ``0/E@``#Y````\``4/Y%@!`#YP```L",$`/D`.$#Y8`@`^0``
M`/``(#^18`P`^8``@%(@!`"Y``"`T@`$`)%?``!K3`4`5$`0`!%UP@*10@P`
M$0$``+"`S""+(<`;D00`@-)_:"#XH`Y`^1#__Y?T`P`J@```-:`.0/E<__^7
M]`,`*G7"`I&@#D#Y-/__EP```/``/#>1FP``E&`!`+6@"D#YH```M0```/``
M$#:1E0``E*`*`/E@P@*1``A`^4```+3A!0"4<\("D6`.0/F#__^7IO[_E^`#
M%"KS4T&I]1-`^?U[Q:C``U_6`1``$:9X8/B!S"&+9F@A^-#__Q<=`(#2'@"`
MTN`#`)&A``#P(4`ND1_L?)(!```4`81`^*0``/"C``#P!0"`TN(#`*J@``#P
MA,Q'^6/81_D`P$?Y"___%\```)``X`&1P0``D"'@`9$_``#KP```5*$``/`A
MU$?Y80``M/`#`:H``A_6P`-?UL```)``X`&1P0``D"'@`9$A``#+0@"`TB'\
M0Y,A#,*:P0``M*(``/!"\$?Y8@``M/`#`JH``A_6P`-?UL```)`!X$$YX0(`
M-?U[OJG]`P"1\PL`^?,#`*J@``#P`.A'^8```+3```"0``!`^?/^_Y?8__^7
MH```\`#01_F```"T(```T`!`+9%X_O^7(`"`4F#B`3GS"T#Y_7O"J,`#7];`
M`U_6H```\`#L1_D@`0"T_7N_J<$``)`@``#0_0,`D2$``I$`0"V1X/[_E_U[
MP:C,__\7_7N\J?T#`)'S4P&I]5L"J?=C`ZD`!0"T]@,`JJ```/``X$?Y%P!`
M^7<$`+3X`P&JX@,6JD``0#D?]`!Q!!A`>B$#`%1"`!9+]0,7JE-\0).T`D#Y
MU`$`M.(#$ZKA`Q:JX`,4JGS^_Y<@`@`U@&IS.!_T`''!`0!4M0(7RW,&`)&4
M`A.+M?Y#DQ4#`+G@`Q2J\U-!J?5;0JGW8T.I_7O$J,`#7]9"!`"1X___%[4B
M`)'H__\7%`"`TO7__Q?]>[VI_0,`D?,+`/FS``#P<^9'^6$"0/GA%P#Y`0"`
MTN&3`)'(__^7XA=`^6$"0/E!``'*00``M/3^_Y?S"T#Y_7O#J,`#7];]>[RI
MH0``\/T#`)'S4P&I]`,`JO,#`:H@Y$?Y]5L"J;4``/`"`$#YXA\`^0(`@-+V
MTP"1M>)'^>$#%JK@`Q2JK___E^```+5AYD?YXA]`^2``0/E```#*0`$`M-G^
M_Y>@`D#YXC>`N0(,`HM`!$#Y0```^2#^_[1"(`"1_/__%_-30:GU6T*I_7O$
MJ,`#7];]>[JI_0,`D?5;`JFV``#P]0,`JL#F1_GS4P&I\P,!JO=C`ZGY:P2I
M`0!`^>$O`/D!`(#28`)`.1_T`'%!``!4<P8`D>`#$ZJV_O^7X5,!D?<#`*K@
M`Q6JA?__E_0#`*H``@"TK_[_EQ\`%^MC!@!4`0"`TF!J83B`:B$X(00`D:#_
M_S4``(!2UN9'^>(O0/G!`D#Y00`!RH$)`+2E_O^7M```\(#B1_D:`$#Y``"`
MTD(C`-'X`P`J``0`D4%X8/BA__^UP0``D``+`!$BL$"Y`'Q]DR(!`#3A`P"J
MX`,:JK#]_Y>!XD?Y(```^:`!`+4``(`2Y?__%R(`@%(BL`"YZ/W_E_D#`*I`
M__^T`G]]D^$#&JKG_?^7@.)'^1D``/F4XD?Y`']`DP`$`)&!`D#Y/W@@^/A7
M`+GA`Q6J(`!`.1_T`'$$&$!ZP0,`5+0``/#X5X"Y(0`5R^`*`)&4XD?Y&/-]
MTP#`(8N9`D#YS?W_ER!K./C@^_^TX5>`N8`"0/D!>&'XX@,!JJ`60#@A!`"1
M(/`?.&```#0?]`!Q0?__5*`'@%)````Y``"`TF)J8#@B:"`X``0`D:+__S6R
M__\7(00`D=[__Q?S4T&I]5M"J?=C0ZGY:T2I_7O&J,`#7];]>[*I_0,`D?5;
M`JFV``#PP>9'^?-3`:GW8P.I^6L$J2(`0/GB;P#Y`@"`TH`"`+0!`$`Y]`,`
MJB$"`#15_?^7]P,`JL`!`+08``#0&0``T!CO-)$YZS21^F,!D>`#%ZJ`_?^7
M\P,`JF`!`+7@`Q>JJ/W_E^`#%*H"_O^7UN9'^>%O0/G``D#Y(```RF`%`+0P
M_O^7<TX`D>$#&*K@`Q.J;/W_E\#]_S3A`QFJX`,3JFC]_Y=`_?\TX`,4JB'^
M_Y?U`P"JX`,3JA[^_Y>@`@`+``@`$0!\0)-Z_?^7XP,3JN(#%*KU`P"J`0``
MT"'T-)$$_O^7X0,:JN`#%:KQ_?^7'P0`,4`!`%3@:T"Y``P4$A\00''!``!4
MX`,5JKG__Y?@`Q6JX_W_E\W__Q?@`Q6J8/W_E_O__Q?S4T&I]5M"J?=C0ZGY
M:T2I_7O.J,`#7];]>[6I_0,`D?-3`:FS``#P]`,`JF'F1_DB`$#YXE<`^0(`
M@-+AHP"18OW_ET`"`#7A.T"Y`@"44B$,%!(_$$!Q)!!">L$``%3@`Q2J00"`
M4A#]_Y<?``!QX!>?&G/F1_GB5T#Y80)`^4$``<J!``"TY/W_EP``@%+Y__\7
M\U-!J?U[RZC``U_6_7N_J:```/#]`P"1`-Q'^0``0+G!_?^7_7O!J*(``/`C
M``#0`0``T$+T1_ECL"B1(0PUD;']_Q?]>[ZI_0,`D?,+`/FS``#P<]Y'^6`"
M0+FR_?^7Z___EV`"0+FO_?^7\PM`^00``-#]>\*HA!`_D>,#!*H%`(!2`@``
ML`$``-!"<!"1(7PUD>C\_Q<,"H32_V,LR_U[`*G]`P"1]5L"J;8``/#`YD?Y
M\U,!J?3C`)$!`$#YX2<0^0$`@-+K_/^7XP,`*@0``-#@`Q2JA-`UD0(``-`A
M`(+20N`UD<_\_Y<?!``Q`0$`5`,`@-+`YD?YX2=0^0``0/D@``#*(`4`M)[]
M_Y<!?$"3/P1`\4D``%0`?2#4H/[_-P`(@M+S8R"+X0,3JN`#%*H"`(+2+_W_
ME_0#`*J@_?\W``0`$0!\0)/J_/^7XP,`J@#]_[25?D"3'P`3ZX(``%0``!6+
M?P(`ZX/]_U1_`!/KB0``5&`"%8M_``#KX_S_5"``@E*?`@!KC/S_5.`#`ZKB
M`Q6JX0,3JFK]_Y?C`P"J'V@U.-3__Q?@`P.J#`J$TOU[0*GS4T&I]5M"J?]C
M+(O``U_6M/__%PP>@M+_8RS+_7L`J?T#`)'U6P*IM0``\/-3`:GT`P"J\P,!
MJJ#F1_GW8P.I^6L$J?LK`/D!`$#YX7<(^0$`@-(```#0`!`VD5K^_Y?X`P"J
MX06`4N`#%*K@_/^78`$`M````-#A`Q2J`#0VD8?^_Y>UYD?YX7=(^:`"0/D@
M``#*0`D`M$W]_Y?@`Q2J1_W_EQ8``-#Y`P`JP6HVD>`#$ZH:``#0&P``T"C]
M_Y=:[S21\P,`JGMS-I'WHP.1,_W_M&`"0#D?``!Q<Q*:FE@!`+3A`Q.JX`,8
MJGC\_Y?````UP6HVD0``@-(8_?^7\P,`JO/__Q?@`Q.J+/W_EV'"((LA\%\X
M/[P`<2`"`%0A!P`1(```"Q_\/W%,^O]4Y0,4JN0#&ZKC`Q.JX`,7J@(``-`!
M`(+20K0YD4C\_Y<`!``1'P1`<:D``%0`?2#4``0`47_*(#CJ__\7X:,!D>`#
M%ZKR_/^7X/O_->![0+D`#!02'R!`<6'[_U3@`Q>J(0"`4C+\_Y?@^O\UX0,7
MJ@```-``-#:1/?[_E^`#%ZI[_/^7]`,`JK/__Q?@`Q2J#!Z"TOU[0*GS4T&I
M]5M"J?=C0ZGY:T2I^RM`^?]C+(O``U_6X0,`JB(`0#E"```UP`-?UB$$`)%?
MO`!Q`!"!FOK__Q?`!P"T_7N^J?T#`)'S"P#Y\P,`J@$`0#G!```U````T`#L
M-)'S"T#Y_7O"J%O\_Q?B_/^7`@0`T6("`HM_`@+K@@,`5$``0#D?O`!QH`(`
M5$$`0#G@`P*J0@0`T3^\`'%!`@!4X@,`JD($`-%_`@+K@@``5$``0#D?O`!Q
M8/__5$(`$\M`"`"1'P1`\2@#`%1"!`"17P1`\<D!`%0`?2#40@0`T>;__Q=_
M`@+K(_W_5'\"`NNA_?]48`)`.1^\`''@^O]4````T`!P-I'6__\7PP``D&-`
M`Y'A`Q.JX`,#JEK\_Y?S"T#Y_7O"J,`#7]8``(#2_/__%P```-``[#21R___
M%_U[N:G]`P"1\U,!J;,``/`4``#08.9'^?5;`JD5``#0]QL`^18``-`7``#0
M]Y8WD0$`0/GA-P#Y`0"`TB```-``L"B1`"@`D0(,0*GB#P2I`@Q!J>(/!:D`
M0$!YX,,`>0```-``>#:1I_W_EP```-``G#:1I/W_EP```-``O#:1H?W_EP``
M`-``X#:1GOW_EZ#^-I&<_?^7````T``\-Y&9_?^7P!(VD9?]_Y>`;C>1E?W_
ME^`#%ZJ3_?^7````T`"\-Y&0_?^7````T``T-I&-_?^7````T`#D-Y%X_?^7
M@```M.$#`*K@`Q>JJOW_EP```-``*#B1<?W_E^$#`*J```"T````T`!4-)&B
M_?^7````T`!P.)%I_?^7X0,`JJ`!`+3`$C:1F_W_EZ#^-I$!``#0(2`YD9?]
M_Y=SYD?YX3=`^6`"0/D@``#*0`(`M%W\_Y<```#0`+`XD5C]_Y?A`P"J8```
MM(!N-Y'O__\7]@,!D0$``-#`1@"1(?0XD4(!@-*T^_^7(/W_-<%N`)'V__\7
M\U-!J?5;0JGW&T#Y_7O'J,`#7];]>[ZI_0,`D?,+`/G3``"08`I`N1\$`#%!
M`0!4````T`!L-Y$\_?^70`$`M```0#D``0`T'\``<>`'GQI@"@"Y8`I`N?,+
M0/G]>\*HP`-?U@``@%+Z__\7_7N_J?T#`)$S_/^7OOO_ET```+0``$#Y_7O!
MJ,`#7];]>[VI_0,`D?5;`JD5``#0MBHYD?-3`:GS`P"JX`,6JA_]_Y>```"T
M`0!`.?0#`*KA```UX0,3JJ`J.9'S4T&I]5M"J?U[PZA+_?\7X0,3JI'[_Y>`
M`@"UX`,3J@[\_Y?U`P"JX`,4J@O\_Y>@`@"+``@`D6C[_Y?D`Q2J]0,`JN(#
M$ZH#``#0`0``T&-H-I$AM#F1\/O_E^$#%:K@`Q:JY___%_-30:GU6T*I_7O#
MJ,`#7]8,,I#2_V,LR^$C0)']>P"I_0,`D?=C`ZFW``#P&```T/5;`JGV`P"J
MX.9'^?-3`:GY:P2I^W,%J0(`0/DBQ`#Y`@"`TL```)``(`"1`HQ`J>(/!JD"
M#$*IX@\)J0(,0ZGB#PJI`@Q$J>(/"ZD"#$6IXH\'J0$,0/GA.P#Y`#!`^>!'
M`/D`$S:1V/S_E^`!`+0!`$`Y\P,`JH$!`#2L__^7X`,3JD?[_Y?S`P"J]^9'
M^>`C0)$!Q$#YX`)`^2```,J@)P"TR_O_EYG__Y?S`P"J``(`M?3C`9&``D#Y
M@```M1,``-!S:CF1"@``%+_\_Y=@``"UE"(`D?C__Q<!`$`YH?__-"_[_Y?S
M`P"J0/__M.`#$ZJS^_^7`/A_TQ4``-``!`"1M88YD0[[_Y?Z`P"J]`,`JF("
M0#F"!P`U]$,"D9,"0/F3`0"TX`,3JJ?\_Y?S`P"J8`<`M`$`0#DA!P`TI/W_
ME^`&`#3@`Q.J%?O_E_,#`*KU@P&1LP``M;0"0/ET``"T@`)`.0`&`#7@`Q.J
ME/O_E_D#`*K@`QJJD?O_ESD#``LY$Q`1%0``T#E_0)/@`QFJZ_K_E^4#&JJC
M<C:1X@,3J@0``+"$F#F1]`,`J@$``+`AK#F1<OO_E^`#%*H!.(!25_O_EQ\$
M`#'A`P!44/O_EP0`0+F?1`!Q8`,`5*```-`!``"PP@)`^>,#%*H`Q$?Y(=`Y
MD0``0/DI^_^7$P"`TJ+__Q?@`Q2JX0,5JG,&`)&4"@"16OO_E[[__Q>4(@"1
MO___%^`#%*II_?^7@```-.`#%*K:^O^7\P,`JK4B`)'%__\7X0,#D>`#%*K,
M^O^7^P,`*D`!`#2@``#0XP,4JL("0/D!``"P`,1'^2&\.I$``$#Y"OO_E^'_
M_Q?@TT"Y``P4$A\00'&!_O]4\]M`N5/[_Y=_`@!K`?[_5.#30+D`(``2'P`'
M<8']_U3@`QFJH_K_E_,#`*H```"P`%0YD4'\_Y=@"P"UV0)`^>`#&:H[^_^7
M^@,`JA\,`'&-`P!4`'Q`DP$``+``$`#1(0@\D2`#`(MV^O^7H`(`-5\3`''`
M``!46A,`43K#.HM`\U\X'[P`<<$!`%36!D#YE@$`M.`#%JHF^_^7'PP`\0D!
M`%0`$`#1`0``L,`"`(LA'#R18_K_EQ\``'$Y$Y::V?[_ER`-`#7@`QFJ`0"`
M4I3Z_Y?V`P`J@`P`-$(`@%(A`H"2^2,&D4[Z_Y?A`QFJX`,6*L(`@-+6^O^7
MX"-&.2`&`#7@)T8Y'PP!<<$%`%3@*T8Y'P0!<6$%`%3@+T8Y'PP!<0$%`%3@
M,T8Y'R`!<:$$`%3@-T8Y'Q0!<4$$`%1"`(!2(0>`DN`#%BHU^O^7X0,9JN`#
M%BHB!8#2O?K_EP4``+#D`QFJI1`_D0$``+"C<C:1X@,4JB$P/)'@`Q.JW/K_
ME^`#%*K&^O^7X0,3J@`3-I$?_/^7X`,3JL#^_Y<7__\7V0)`^5KZ_Y?A`P"J
MX`,9JG7]_Y?Y`P"J(/3_M9___Q<"`(!2`0"`TN`#%BH4^O^7MP4`E/H#`*H"
M`)#2X0,9JN`#%BJ:^O^7X@,`JA\``'$L`P!4X`,6*OEC!9&,^O^7_`,9JN$#
M&JH:``"P6H<YD18`@-+[`P61X`,;JA<&`)1B:W8XX`,9JN$#&JK6!@"1.0L`
MD:[Z_Y??4@#Q(?__5`4``+#D`QRJI1`_D?\#!CG&__\7X0,9JN`#&JJK!0"4
MWO__%P$``+`A(#F1&0``L#FG/)$```"P`&PWD>3[_Y>U<C:1ZOG_EQ8``+#6
M$C^1Y`,`*N4#%JKC`Q6JX@,4JN`#$ZH!``"P(6P\D9#Z_Y?@`Q.J`3B`4G7Z
M_Y<?!``Q`?;_5&[Z_Y<``$"Y'T0`<8'U_U36^?^7>P<`$>0#`"KF`Q:JY0,;
M*N,#%:KB`Q2JX0,9JN`#$ZI]^O^7[?__%^`#$ZH,,I#2_7M`J?-30:GU6T*I
M]V-#J?EK1*G[<T6I_V,LB\`#7];]>[JI_0,`D?-3`:FS``#0]5L"J77>1_GW
M8P.I^6L$J?MS!:F@`D"Y8_K_E_0#`*J@`D"Y8/K_EX'B0CD!Y`(Y````L`#\
M-I%Q^_^7P```M`$`0#D_Q`!Q80``5``$0#E````TN_W_EW;>1_FT``#PP`)`
MN5#Z_Y<!``"P8P&`4B'H/)$B`(!2Y_G_ER`$`+5VWD?YP`)`N4?Z_Y=C`(!2
M(@"`4@$``+`A_#R1WOG_E_4#`*H`"@"U=]Y'^>`"0+D]^O^78P"`4B(`@%(!
M``"P(1@]D=3Y_Y?U`P"J0`P`M````+``-#:12?O_E_8#`*I`"@"TX`)`N2_Z
M_Y>A"D#YX@,6JB$`0/G/^?^75@``%``(0/D;@(!2FL("D34`@%(;!*!R&!1`
M^;D&`%%!!T"YP`)`N3\`%6L-`0!4'OK_ER)_0)/A`QBJ`P"`4G[Y_Y?W`P"J
M0`$`M8#"`I$!!$"Y(00`43\`&6M!^?]4=]Y'^?4#`*HV`(!2&@``%`$`0/E`
M!T#Y'-AU^"`,0+D``!L*'P`0<>$``%0A"$#YX`,<JEWY_Y>@_?\UM08`$=__
M_Q?``D"Y`/K_E^$"0/E#`(!2`@"`T@SZ_Y?A`P"J]/__%]8&`!'X^?^7X0,8
MJB+Y_Y>A!D"YX`)`N3\`%FLL__]4J/__%\`"0+GO^?^7H0I`^0(``+!"!#V1
M(0!`^8[Y_Y>@"D#Y``!`^0`,0+G@]+<VP`)`N>3Y_Y>A"D#Y(0!`^4WY_Y>A
M__\7//S_E_8#`*K@`D"Y]@0`M-OY_Y>A"D#YX@,6JB$`0/E[^?^7X`,6JL7Y
M_Y=SWD?Y8`)`N=+Y_Y?U`P"J8`)`N<_Y_Y<B`(!2`0``L"$@/9$#^?^7`@``
ML.$#`*I"=#V1X`,5JFKY_Y=@`D"YD\("D</Y_Y<?Y`(Y````L``0-I'5^O^7
M8`H`^<`!`+5@!D#YU_W_EV`*`/E``0"U````L`",/9'^^/^7M?G_EX'"`I$B
M!$#YH0I`^4(`0/F$__\7E,("D0$X@%*`"D#YF/G_E^,#`"H?1`!Q(`$`5``$
M`!$?!`!QR0``5("*0*D!`$#Y````L``0/I'I^/^7\U-!J?5;0JGW8T.I^6M$
MJ?MS1:G]>\:HP`-?UOU[OJG]`P"1\U,!J?,#`*J[_/^7LOS_E_0#`*IC_?^7
MP`$`-+,!`+1@`D`Y8`$`-.`#%*H!``"P(9@YD1[Y_Y>?`@#KH0``5.`#$ZKS
M4T&I_7O"J$C[_Q?S4T&I_7O"J,`#7];_PPK1J```T`7@`)$'X`&1_7L`J?T#
M`)$!Y4?Y\PL`^2(`0/GB5P'Y`@"`TN*C`)'F`P*JH0!`N<9``)&DA$#X(0C`
M6L$`'_C_``7K@?Q@TR,<"%,AW'C3(1QPDF$``:J#_&C38QQXDF3@1*HA``2J
MP8`?^`'^_U0#"(!21"!`^6,$`'%!-$#Y0B``D46`7_@A``3*1`1`^80`!<HA
M``3*)/Q?TX$$`:HA?$"203P`^6'^_U0),$"I)C./T@HL0:E&4*OR#1!`^27]
M6].'_4+3I10)JN=X#*IA`0K*\'Q`DB$`#(H$`@K*(0`+RH0`"8HE0"6+A``*
MRN$70/F$``N+(OU"TR$`!HM">`FJI0`!B^,``LKA&T#YI0`-"V,`!8I.?$"2
M(0`&BV,`$,J$``&+H?Q;TR$4!:IC``J+CP`!BX0``0OA'T#Y(0`&BV,``8OA
M?7O3[WT;4R$`#ZIG``&+8P`!"Z'\0M,E>`6J00`%RJ]\0)+B(T#Y(0`$BB$`
M#LI"``:+(0`0BR$``HOB?'O3YWP;4T(`!ZHP``*+(0`""X+\0M-$>`2JH@`$
MRH=\0)+E)T#Y0@`#BD(`#\JE``:+0@`.BT(`!8L%?GO3$'X;4Z4`$*I0``6+
M0@`%"V7\0M.C>`.JA0`#RFY\0)+D*T#YI0`!BJ4`!\J$``:+I0`/BZ4`!(L$
M?GO3$'X;4X0`$*JP``2+I0`$"R3\0M.!>`&J9``!RB]\0)+C+T#YA``"BH0`
M#LIC``:+A``'BX0``XL#?GO3$'X;4V,`$*J0``.+A``#"T/\0M-B>`*J(P`"
MRD=\0)+A,T#Y8P`%BF,`#\HA``:+8P`.BV,``8L!?GO3$'X;4R$`$*IP``&+
M8P`!"Z'\0M,E>`6J00`%RJY\0)+B-T#Y(0`$BB$`!\I"``:+(0`/BR$``HL"
M?GO3$'X;4T(`$*HO``*+(0`""X+\0M-$>`2JH@`$RI!\0)+E.T#Y0@`#BD(`
M#LJE``:+0@`'B^=]>]/O?1M3YP`/JD(`!8M%``>+0@`'"V?\0M/C>`.JAP`#
MRF]\0)+D/T#YYP`!BN<`$,J$``:+YP`.B^<`!(ND?'O3I7P;4X0`!:KQ``2+
MYP`$"R3\0M.!>`&J)'Y[TV4``<HQ?AM3XT-`^:4``HJE``_*A``1JF,`!HNE
M`!"+I0`#BRY\0)*C``2+I0`$"T3\0M.">`*J)``"RE!\0)+A1T#YA``'BH0`
M#LHA``:+A``/BX0``8MA?'O38WP;4R$``ZJ1``&+A``!"^'\0M,G>`>J0P`'
MRN]\0)+A2T#Y8P`%BF,`$,HA``:+8P`.BV,``8LA?GO3,7X;4R$`$:IQ``&+
M8P`!"Z'\0M,E>`6JX@`%RJY\0)+A3T#Y0@`$BD(`#\HA``:+0@`0BT(``8LA
M?GO3,7X;4R$`$:I0``&+0@`!"X'\0M,D>`2JH0`$RH=\0)+E4T#Y(0`#BB$`
M#LJE``:+(0`/BR$`!8L%?GO3$'X;4Z4`$*HO``6+(0`%"V7\0M.C>`.J\7U[
MTX0``\IE?$"2A``"BN]]&U.$``?*,0(/JH0`#HON5T#YS@$&BX0`#HM._$+3
MPGD"JI``$8MC``+*3WQ`DF,``8H.?GO38P`%RA!^&U-C``>+S@$0JN=;0/F$
M`!$+YP`&BY'\0M-C``>+9P`.BV,`#@LN_$+3P7D!JD(``<HN?$"20@`$BB1Z
M!*I"``_*(0`$RD(`!8LA``.*Y5]`^2$`#LHA``^+I0`&BT(`!8OE?!M3YV@;
M4^<`!:IE_$+34``'BT(`!POG8T#YHW@#JH4``\KF``:+1_Q;T^<4`JHA``:+
MYF=`^2]`)XNE`!!*X0`!"R=TG=*E``Z+)]NM\L8`!XNF``:+)?Q;TZ44`:K.
M0"6+I0`&"T;\0M/">`*J<0`"RC$"#THQ0B2+Y&M`^80`!XLD`@2+L?Q;TS$6
M!:J00#&+,0($"R3\0M.!>`&JI/Q"TX5X!:I/``'*[P$.2BX`!<K.`1!*XT$C
MB\)!(HOONTVI[P$'B\X!!XMC``^++_Y;T^\5$:I"``Z+9D`OB^,!`PMN_%O3
M;_Q"T\X5`ZKO>0.J1$`NB\(!`@LN_D+3T7D1JD[\0M.P`!'*SGD"JA`"!DH!
M0B&+\'=`^1`"!XLA`!"+4/Q;TQ`6`JKB`0[*)D`PBQ`"`0LA`@_*0@`&2B$`
M!$I10#&+)4`EBP3^6]/A"T^IA!00JB$`!XM"``>+I0`!BP'^0M.C0"2+A0`%
M"S!X$*HQ`@*+LOQ;TZ'\0M-2%@6J)7@%JL8!$,H$`@7*(D(RB\8``TJ$``)*
MST`OBXY`+HM1`A$+YA-0J2+^0M/&``>+A``'B^\!!HLF_EO3QA01JE%X$:JC
M`!'*S@$$B_-!)HO&``\+8P`32L3\6]//_$+3A!0&JG!`,(OF>0:JXS]1J=Y!
M)(N$``X+(0(&RB$`'DHA0"6+COQ"TV,`!XOO`0>+$`(#BX/\6]-C%`2J(0`/
MB\1Y!*H30B.+8P`0"\(`!,IR_%O3</Q"TU(6`ZH#>@.JA0`#RD(`$THO0#*+
M00(!"Z4`#TI"0#&+ID`FBS'\6]/N%U*I,18!JB_\0M/A>0&JS@$'BZ4`!XM"
M``Z+;@`!RE-`,8LB`@(+S@$32L8`!8O$022+1?Q;T^Z;0/FE%`*JS@$'B]!`
M)8N$``Z+3OQ"T\)Y`JJE``8+)@`"RL8`$$JQ_%O3PT`CBS$6!:KFGT#YDT`Q
MBR0"!`O&``>+8P`&BZ;\0M/%>`6JD/Q;TT\`!<H0%@2J[P$32N]!(8N!_$+3
M(7@$JG)`,(OF$U2I`P(#"ZX``<IP_%O3S@$22A`6`ZK.02*+8OQ"T\8`!XM"
M>`.J[P$&BX0`!XOF03"+#P(/"\X!!(LC``+*Y/U;TV,`!DJ$%`^JYOU"T\]X
M#ZIE0"6+T4$DBT8`#\K&`!%*A``."\%`(8OC&U6ICOQ"TV,`!XO&``>+I0`#
MBX/\6]-C%`2JQ'D$JB$`!HNR0".+8P`%"^4!!,JE`!)*<?Q;TZ)`(HLQ%@.J
MY;-`^3``$8LA`!$+IP`'BV7\0M-"``>+!WY[TQ!^&U.C>`.JYP`0JF8`!`I.
M``>+0@`'"X<``ZJ%FY?2YP`!BF7CL?+G``:JYD`OB^>W0/GG``6+Q@`'B\=]
M>]/.?1M3YP`.JLX`!XO&``<+)_Q"T^%X`:IG``&J+P`#"N<``HKG``^JY$`D
MB^>[0/GG``6+A``'B\=]>]/.?1M3YP`.JHX`!XN$``<+1_Q"T^)X`JHG``*J
M3P`!"N<`!HKG``^JXT`CB^>_0/GG``6+8P`'B\=]>]/.?1M3YP`.JFX`!XMC
M``<+Q_Q"T^9X!JI'``:JSP`""N<`!(KG``^JX4`AB^?#0/GG``6+(0`'B\=]
M>]/.?1M3YP`.JBX`!XLA``<+A_Q"T^1X!*K'``2JCP`&"N<``XKG``^JXD`B
MB^?'0/GG``6+0@`'B\=]>]/.?1M3YP`.JDX`!XM"``<+9_Q"T^-X`ZJ'``.J
M;P`$"N<``8KG``^JYD`FB^?+0/GG``6+Q@`'B\=]>]/.?1M3YP`.JLX`!XO&
M``<+)_Q"T^%X`:IG``&J+P`#"N<``HKG``^JY$`DB^?/0/GG``6+A``'B\=]
M>]/.?1M3YP`.JHX`!XN$``<+1_Q"T^)X`JHG``*J3P`!"N<`!HKG``^JXT`C
MB^?30/GG``6+8P`'B\=]>]/.?1M3YP`.JFX`!XMC``<+Q_Q"T^9X!JI'``:J
MSP`""N<`!(KG``^JX4`AB^?70/GG``6+(0`'B\=]>]/.?1M3YP`.JBX`!XLA
M``<+A_Q"T^1X!*K'``2JCP`&"N<``XKG``^JXD`BB^?;0/GG``6+0@`'B\=]
M>]/.?1M3YP`.JDX`!XM"``<+9_Q"T^-X`ZJ'``.J;P`$"N<``8KG``^JYD`F
MB^??0/GG``6+Q@`'B\=]>]/.?1M3YP`.JLX`!XO&``<+)_Q"T^%X`:IG``&J
M+P`#"N<``HKG``^JY$`DB^?C0/GG``6+A``'B\=]>]/.?1M3YP`.JHX`!XN$
M``<+1_Q"T^)X`JHG``*J3P`!"N<`!HKG``^JXT`CB^?G0/GG``6+8P`'B\=]
M>]/.?1M3YP`.JFX`!XMC``<+Q_Q"T^9X!JI'``:JSP`""N<`!(KG``^JX4`A
MB^?K0/GG``6+(0`'B\=]>]/.?1M3YP`.JBX`!XLA``<+A_Q"T^1X!*K'``2J
MCP`&"N<``XKG``^JXD`BB^?O0/GG``6+0@`'B\=]>]/.?1M3YP`.JDX`!XM"
M``<+9_Q"T^-X`ZJ'``.J;P`$"N<``8KG``^JYD`FB^?S0/GG``6+Q@`'B\=]
M>]/.?1M3YP`.JLX`!XO&``<+)_Q"T^%X`:IG``&J+P`#"N<``HKG``^JY$`D
MB^?W0/GG``6+A``'B\=]>]/.?1M3YP`.JHX`!XN$``<+1_Q"T^)X`JK1?7O3
M)P`"JD\``0KG``:*SGT;4^<`#ZHQ`@ZJXT`CB^?[0/GG``6+8P`'BW``$8MQ
M`!$+P_Q"TV9X!JI'``:JPP`""N<`!(KG``.JX_]`^>%`(8MC``6+(0`#BP-^
M&U,0:AM3$`(#JH/\0M-D>`2J+@`0B\<`!*J#``8*YP`1BB$`$`OG``.J(_Y"
MT^)`(HMQ>!&JYP-!^2_\6]/O%0&J@P`1RN4`!8MC``Y*0@`%BV-`)HM'0"^+
MX@$""^8'0?DP_$+3$'H!JD[\6]/%.IC2(0(0RD5,N?+.%0*JQ@`%BR$`!TIC
M``:+)$`DBV9`+HM/_$+3S@$#"^]Y`JKA"T'Y`P(/RL?]6]-C``9*YQ0.JB$`
M!8OF#T'YA``!BY)`)XOG``0+Q@`%BW%`,8O#_4+3,0(&BVYX#JKF_%O3Y!-!
M^<84!ZKA`0[*(0`22C-")HN$``6+Q@`1"S!`,(L0`@2+Y/Q"TX=X!ZK2_%O3
M4A8&JL(!!\I"`!-*T?Q"TP%",HM/0"^+4`(0"R9Z!JKB%T'YXP`&RA+^6]-C
M``%*4A80JD(`!8OA&T'Y[P$"B^)!,HL$_D+33P(/"Y!X$*HA``6+;D`NB\X!
M`8O$`!#*X?U;TX0``DHA%`^JAT`GB^(?0?G102&+(0`."^/]0M-"``6+;W@/
MJN<``HLB_%O3`P(/RD(4`:IC`!%*+OQ"T_-`(HMF0":+0@`'"\%Y`:KC(T'Y
M4?Q;TS$6`JI'_$+38P`%B^)X`JK&``.+Y`$!RMY`,8LF`@8+[B=!^2,``LJ$
M`!-*8P`>2H1`,(O0_%O3$!8&JLX!!8MC0"^+S_Q"T^9Y!JJ$``Z+DD`PBTX`
M!LK.`1)*!`($"\%!(8ON+T'YD/Q;T^<K0?G.`06+$!8$JB$`#HOG``6+COQ"
MT\1Y!*IC``>+?D`PB\<`!,KG`!Y*`P(#"^)`(HOG,T'Y</Q;TQ`6`ZKG``6+
M0@`'BV?\0M/C>`.J,D`PBX\``\H!`@$+[P$22N]!)HLP_%O3YC=!^1`6`:H(
MY4?YQ@`%B^\!!HLF_$+3P7@!JE%`,(MN``'*`@(""\X!$4K.022+4/Q;T^0[
M0?D0%@*JA``%B_)!,(O.`02+1/Q"TX)X`JH/`@\+)P`"RN<`$DKP_5O3YT`C
MBQ`6#ZKC/T'YT4$PBPX"#@MC``6+YP`#B^/]0M-O>`^JT/U;TT8`#\H0%@ZJ
MQ@`12L9`(8OR0#"+X4-!^0<"!PLA``6+\/Q;T\8``8O!_4+3+G@.JA`6!ZKD
M`0[*A``22M%`,(N$0"*+!@(&"^)'0?GP_$+3!WH'JM#\0M-"``6+PP$'RH0`
M`HO"_%O30A0&JF,`$4IC0"^+!GH&JI)`(HM"``0+Y$M!^4_\6]/O%0*JX0`&
MRH0`!8LA`!)*8P`$BR%`+HMQ0"^+XP$#"^]/0?E$_$+3@G@"JBE!)XOO`06+
MS0`-"R$`#XMO_%O3[Q4#JDL`"PLA``^+#1``^2P`#`LN?!M3)&@;4X0`#JK.
M``+*S@$12F'\0M.$``Z+(7@#JNY30?DJ``H+"BP!J<4!!8NE``F+A0`%"P4P
M`*GA5T'Y``%`^2```,I```"T*?7_E_U[0*GS"T#Y_\,*D<`#7];]>[^I`!"`
MTOT#`)%]]/^7'_P"J2)@A-*BZ*SR`@``^2)QE=(?>`"YHOF]\@($`/G"GYO2
M0A>S\@((`/G"CHK20@:B\@(,`/D"/IS20GJX\@(0`/G]>\&HP`-?UOU[O*G]
M`P"1\U,!J?,#`*I`?$"3]5L"J?0#`*IB%D#Y]QL`^4,,``M?``/KB0``5&(:
M0/E"!`"18AH`^6(:0/EUX@"10'1`BV."`JE@>D"Y@`,`-!8(@%+6`@!+GP(6
M:Z#"((N6TI8:'P`!Z\)^0).B``!4`P`"BS\``^M"``!4`'T@U#<``HL?``'K
M:0``5!\`%^MC__]4U_3_EV!Z0+G``@`+8'H`N1\``7'!`@!4X`,3JDC[_Y>4
M`A9+X0,7JG?B`9&?_@!QC`(`5()^0),_`!7KB0``5*`"`HL_``#K`_W_5#\`
M%>N"``!4(``"B[\"`.MC_/]4X`,5JK[T_Y=T>@"Y\U-!J?5;0JGW&T#Y_7O$
MJ,`#7]8_`!7K:0``5#\`%^OC^O]4/P`5ZS8``9%B``!4OP(6ZT/Z_U0B#$"I
MH@X`J90"`5$B#$&IH@X!J2(,0JFB#@*I(`1#J:`&`ZG@`Q.J'/O_E^$#%JK6
M__\7_7N\J?T#`)'S4P&I]`,`JO,#`:KU6P*I->``D?<;`/D@%$#Y-BA`N3<P
M0+GA#X`2`"`#4]8*P%H"!``1]PK`6E_@`'&ARB`XH,(BBXT)`%0!"(!2(@`"
M2P$`@%)"?$"3Z?/_E^`#$ZK_^O^7?_X#J7_^!*E__@6I?S8`^7=:#BG@`Q.J
M^/K_EV`"0/D`_%C3@`(`.6`"0/D`_%#3@`8`.6`"0/D`_$C3@`H`.6`"0/F`
M#@`Y8`9`^0#\6-.`$@`Y8`9`^0#\4-.`%@`Y8`9`^0#\2-.`&@`Y8`9`^8`>
M`#E@"D#Y`/Q8TX`B`#E@"D#Y`/Q0TX`F`#E@"D#Y`/Q(TX`J`#E@"D#Y@"X`
M.6`.0/D`_%C3@#(`.6`.0/D`_%#3@#8`.6`.0/D`_$C3@#H`.6`.0/F`/@`Y
M8!)`^0#\6-.`0@`Y8!)`^?5;0JD`_%#3@$8`.6`20/D`_$C3@$H`.6`20/F`
M3@`YX`,3JO-30:GW&T#Y_7O$J"OT_Q<!!X!2(@`"2P$`@%)"?$"3GO/_E[O_
M_Q?]>[^I_0,`D?U[P:C``U_6+W1M<`!005)?5$U01$E2`%1%35!$25(`5$U0
M`%5315(`55-%4DY!344`+BX`)7,O)7,`1'EN84QO861E<CHZ8F]O=%]$>6YA
M3&]A9&5R`$EN=&5R;F%L<SHZ4$%2.CI"3T]4`&5X90`O<')O8R\E:2\E<P!0
M05)?5$5-4`!005)?4%)/1TY!344`.@`O`%!%4DPU3$E"`%!%4DQ,24(`4$52
M3#5/4%0`4$523$E/`%!!4E])3DE424%,25I%1`!005)?4U!!5TY%1`!005)?
M0TQ%04X`4$%27T1%0E5'`%!!4E]#04-(10!005)?1TQ/0D%,7T1%0E5'`%!!
M4E]'3$]"04Q?5$U01$E2`%!!4E]'3$]"04Q?5$5-4`!005)?1TQ/0D%,7T-,
M14%.`%!!4E]#3$5!3CT`,0!,1%],24)205)97U!!5$@`4UE35$5-`"4P,G@`
M<&%R+0`E<R5S)7,E<P`E<SH@8W)E871I;VX@;V8@<')I=F%T92!S=6)D:7)E
M8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*`"5S.B!P<FEV871E('-U8F1I
M<F5C=&]R>2`E<R!I<R!U;G-A9F4@*'!L96%S92!R96UO=F4@:70@86YD(')E
M=')Y('EO=7(@;W!E<F%T:6]N*0H`<&%R;``N<&%R`"5S)7-C86-H92TE<R5S
M`"5S)7-T96UP+25U)7,`)7,E<W1E;7`M)74M)74E<P!!4D=6`!@`<&5R;``P
M`%!!4CHZ4&%C:V5R.CI615)324].`#$N,#0Y`%5N86)L92!T;R!C<F5A=&4@
M8V%C:&4@9&ER96-T;W)Y`"5S.B!C<F5A=&EO;B!O9B!P<FEV871E(&-A8VAE
M('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H`+64`+2T`979A
M;"`G97AE8R`O=7-R+V)I;B]P97)L("`M4R`D,"`D>S$K(B1`(GTG"FEF(#`[
M(",@;F]T(')U;FYI;F<@=6YD97(@<V]M92!S:&5L;`IP86-K86=E(%]?<&%R
M7W!L.PIM>2`H)%!!4E]-04=)0RP@)'!A<E]T96UP+"`D<')O9VYA;64L($!T
M;7!F:6QE*3L*14Y$('L@:68@*"1%3E9[4$%27T-,14%.?2D@>PIR97%U:7)E
M($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ0F%S96YA;64["G)E<75I<F4@
M1FEL93HZ4W!E8SL*;7D@)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N
M86UE*"1P87)?=&5M<"D["F]U=',H<7%[4F5M;W9I;F<@9FEL97,@:6X@(B1P
M87)?=&5M<")]*3L*1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@
M*2`_(')M9&ER(#H@=6YL:6YK('TL("1P87)?=&5M<"D["G)M9&ER("1P87)?
M=&5M<#L*:68@*"UD("1P87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2![
M"FUY("1T;7`@/2!N97<@1FEL93HZ5&5M<"@*5$5-4$Q!5$4@/3X@)W1M<%A8
M6%A8)RP*1$E2(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T;W!D:7(I
M+`I3549&25@@/3X@)RYC;60G+`I53DQ)3DL@/3X@,"P**3L*<')I;G0@)'1M
M<"`B(R$O8FEN+W-H"G@],3L@=VAI;&4@6R!<)'@@+6QT(#$P(%T[(&1O"G)M
M("UR9B`G)'!A<E]T96UP)PII9B!;(%PA("UD("<D<&%R7W1E;7`G(%T[('1H
M96X*8G)E86L*9FD*<VQE97`@,0IX/6!E>'!R(%PD>"`K(#%@"F1O;F4*<FT@
M)R(@+B`D=&UP+3YF:6QE;F%M92`N("(G"B(["F-H;6]D(#`W,#`L)'1M<"T^
M9FEL96YA;64["FUY("1C;60@/2`D=&UP+3YF:6QE;F%M92`N("<@/B]D978O
M;G5L;"`R/B8Q("8G.PIC;&]S92`D=&UP.PIS>7-T96TH)&-M9"D["F]U=',H
M<7$H4W!A=VYE9"!B86-K9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A
M;G5P.B`I"BX@)'1M<"T^9FEL96YA;64I.PI]"GT@?0I"14=)3B!["DEN=&5R
M;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT97)N86QS.CI005(Z
M.D)/3U0["B1005)?34%'24,@/2`B7&Y005(N<&U<;B(["F5V86P@>PI?<&%R
M7VEN:71?96YV*"D["FUY("1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["FUY
M("5#;VYF:6<@/2`H"G!A=&A?<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@
M/R`G.R<@.B`G.B<I+`I?97AE("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7
M:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`I?9&5L:6T@("`@("`]
M/B`H)%Y/(#U^("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI.PI?<V5T
M7W!R;V=N86UE*"D["E]S971?<&%R7W1E;7`H*3L*;7D@*"1S=&%R=%]P;W,L
M("1D871A7W!O<RD["GL*;&]C86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT[
M"F]P96X@7T9(+"`G/"<L("1P<F]G;F%M92!O<B!L87-T.PIB:6YM;V1E*%]&
M2"D["FUY("1B=68["FUY("1S:7IE(#T@+7,@)'!R;V=N86UE.PIM>2`D8VAU
M;FM?<VEZ92`](#8T("H@,3`R-#L*;7D@)&UA9VEC7W!O<SL*:68@*"1S:7IE
M(#P]("1C:'5N:U]S:7IE*2!["B1M86=I8U]P;W,@/2`P.PI](&5L<VEF("@H
M;7D@)&T@/2`D<VEZ92`E("1C:'5N:U]S:7IE*2`^(#`I('L*)&UA9VEC7W!O
M<R`]("1S:7IE("T@)&T["GT@96QS92!["B1M86=I8U]P;W,@/2`D<VEZ92`M
M("1C:'5N:U]S:7IE.PI]"G=H:6QE("@D;6%G:6-?<&]S(#X](#`I('L*<V5E
M:RA?1D@L("1M86=I8U]P;W,L(#`I.PIR96%D*%]&2"P@)&)U9BP@)&-H=6YK
M7W-I>F4@*R!L96YG=&@H)%!!4E]-04=)0RDI.PII9B`H*&UY("1I(#T@<FEN
M9&5X*"1B=68L("1005)?34%'24,I*2`^/2`P*2!["B1M86=I8U]P;W,@*ST@
M)&D["FQA<W0["GT*)&UA9VEC7W!O<R`M/2`D8VAU;FM?<VEZ93L*?0IL87-T
M(&EF("1M86=I8U]P;W,@/"`P.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M(#0L
M(#`["G)E860@7T9(+"`D8G5F+"`T.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M
M(#0@+2!U;G!A8VLH(DXB+"`D8G5F*2P@,#L*)&1A=&%?<&]S(#T@=&5L;"!?
M1D@["FUY("5R97%U:7)E7VQI<W0["G)E860@7T9(+"`D8G5F+"`T.R`@("`@
M("`@("`@("`@("`@("`@("`@("`@(",@<F5A9"!T:&4@9FER<W0@(D9)3$4B
M"G=H:6QE("@D8G5F(&5Q(")&24Q%(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*
M<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA
M;64@/2`D8G5F.PIO=71S*'%Q*%5N<&%C:VEN9R!F:6QE("(D9G5L;&YA;64B
M+BXN*2D["FUY("1C<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX
M?2DO?'P@*2`_("0Q(#H@=6YD968["FUY("@D8F%S96YA;64L("1E>'0I(#T@
M*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B
M=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@
M*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI
M)"]I*2!["FUY("1F:6QE;F%M92`](%]T96UP9FEL92@B)&-R8R1E>'0B+"`D
M8G5F+"`P-S4U*3L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65]
M(#T@)&9I;&5N86UE.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M
M97T@/2`D9G5L;&YA;64["GT*96QS:68@*"`D9G5L;&YA;64@/7X@;7Q>+S]S
M:&QI8B]\(&%N9"!D969I;F5D("1%3E9[4$%27U1%35!]("D@>PIM>2`D9FEL
M96YA;64@/2!?=&5M<&9I;&4H(B1B87-E;F%M921E>'0B+"`D8G5F+"`P-S4U
M*3L*;W5T<R@B4TA,24(Z("1F:6QE;F%M95QN(BD["GT*96QS92!["B1R97%U
M:7)E7VQI<W1[)&9U;&QN86UE?2`]"B1005(Z.DAE879Y.CI-;V1U;&5#86-H
M97LD9G5L;&YA;65](#T@>PIB=68@/3X@)&)U9BP*8W)C(#T^("1C<F,L"FYA
M;64@/3X@)&9U;&QN86UE+`I].PI]"G)E860@7T9(+"`D8G5F+"`T.PI]"FQO
M8V%L($!)3D,@/2`H<W5B('L*;7D@*"1S96QF+"`D;6]D=6QE*2`]($!?.PIR
M971U<FX@:68@<F5F("1M;V1U;&4@;W(@(21M;V1U;&4["FUY("1I;F9O(#T@
M9&5L971E("1R97%U:7)E7VQI<W1[)&UO9'5L97T@;W(@<F5T=7)N.PHD24Y#
M>R1M;V1U;&5](#T@(B]L;V%D97(O)&EN9F\O)&UO9'5L92(["FEF("@D14Y6
M>U!!4E]#3$5!3GT@86YD(&1E9FEN960H)DE/.CI&:6QE.CIN97<I*2!["FUY
M("1F:"`]($E/.CI&:6QE+3YN97=?=&UP9FEL92!O<B!D:64@)"$["F)I;FUO
M9&4H)&9H*3L*<')I;G0@)&9H("1I;F9O+3Y[8G5F?3L*<V5E:R@D9F@L(#`L
M(#`I.PIR971U<FX@)&9H.PI]"F5L<V4@>PIM>2`D9FEL96YA;64@/2!?=&5M
M<&9I;&4H(B1I;F9O+3Y[8W)C?2YP;2(L("1I;F9O+3Y[8G5F?2D["F]P96X@
M;7D@)&9H+"`G/"<L("1F:6QE;F%M92!O<B!D:64@(F-A;B=T(')E860@)&9I
M;&5N86UE.B`D(2(["F)I;FUO9&4H)&9H*3L*<F5T=7)N("1F:#L*?0ID:64@
M(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C86YN;W0@9FEN9"`D;6]D=6QE(5QN
M(CL*?2P@0$E.0RD["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@4$%2.CI(
M96%V>3L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CHZ
M2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*<F5Q=6ER
M92!)3SHZ1FEL93L*=VAI;&4@*&UY("1F:6QE;F%M92`]("AS;W)T(&ME>7,@
M)7)E<75I<F5?;&ES="E;,%TI('L*=6YL97-S("@D24Y#>R1F:6QE;F%M97T@
M;W(@)&9I;&5N86UE(#U^("]"4T1004XO*2!["FEF("@D9FEL96YA;64@/7X@
M+UPN<&UC/R0O:2D@>PIR97%U:7)E("1F:6QE;F%M93L*?0IE;'-E('L*9&\@
M)&9I;&5N86UE('5N;&5S<R`D9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI>F5<
M+G!L)"\["GT*?0ID96QE=&4@)')E<75I<F5?;&ES='LD9FEL96YA;65].PI]
M"FQA<W0@=6YL97-S("1B=68@97$@(E!+7#`P,UPP,#0B.PHD<W1A<G1?<&]S
M(#T@*'1E;&P@7T9(*2`M(#0[("`@("`@("`@("`@("`@(",@<W1A<G0@;V8@
M>FEP"GT*;7D@0'!A<E]A<F=S.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H
M+"`D8V%C:&5?;F%M92D["F1E;&5T92`D14Y6>U!!4E]!4%!?4D554T5].R`C
M('-A;FET:7IE("A2155312!M87D@8F4@82!S96-U<FET>2!P<F]B;&5M*0HD
M<75I970@/2`P('5N;&5S<R`D14Y6>U!!4E]$14)51WT["FEF("@A)'-T87)T
M7W!O<R!O<B`H)$%21U9;,%T@97$@)RTM<&%R+6]P=&EO;G,G("8F('-H:69T
M*2D@>PIM>2`E9&ES=%]C;60@/2!Q=R@*<"`@(&)L:6)?=&]?<&%R"FD@("!I
M;G-T86QL7W!A<@IU("`@=6YI;G-T86QL7W!A<@IS("`@<VEG;E]P87(*=B`@
M('9E<FEF>5]P87(**3L*:68@*$!!4D=6(&%N9"`D05)'5ELP72!E<2`G+2UR
M975S92<I('L*<VAI9G0@0$%21U8["B1%3E9[4$%27T%04%]2155317T@/2!S
M:&EF="!`05)'5CL*?0IE;'-E('L@(R!N;W)M86P@<&%R;"!B96AA=FEO=7(*
M;7D@0&%D9%]T;U]I;F,["G=H:6QE("A`05)'5BD@>PHD05)'5ELP72`]?B`O
M7BTH6T%)34]"3&)Q<&EU<U1V72DH+BHI+R!O<B!L87-T.PII9B`H)#$@97$@
M)TDG*2!["G!U<V@@0&%D9%]T;U]I;F,L("0R.PI]"F5L<VEF("@D,2!E<2`G
M32<I('L*979A;"`B=7-E("0R(CL*?0IE;'-I9B`H)#$@97$@)T$G*2!["G5N
M<VAI9G0@0'!A<E]A<F=S+"`D,CL*?0IE;'-I9B`H)#$@97$@)T\G*2!["B1O
M=70@/2`D,CL*?0IE;'-I9B`H)#$@97$@)V(G*2!["B1B=6YD;&4@/2`G<VET
M92<["GT*96QS:68@*"0Q(&5Q("=")RD@>PHD8G5N9&QE(#T@)V%L;"<["GT*
M96QS:68@*"0Q(&5Q("=Q)RD@>PHD<75I970@/2`Q.PI]"F5L<VEF("@D,2!E
M<2`G3"<I('L*;W!E;B`D;&]G9F@L("(^/B(L("0R(&]R(&1I92`B6%A8.B!#
M86YN;W0@;W!E;B!L;V<Z("0A(CL*?0IE;'-I9B`H)#$@97$@)U0G*2!["B1C
M86-H95]N86UE(#T@)#(["GT*<VAI9G0H0$%21U8I.PII9B`H;7D@)&-M9"`]
M("1D:7-T7V-M9'LD,7TI('L*9&5L971E("1%3E9[)U!!4E]414U0)WT["FEN
M:71?:6YC*"D["G)E<75I<F4@4$%2.CI$:7-T.PHF>R)005(Z.D1I<W0Z.B1C
M;60B?2@I('5N;&5S<R!`05)'5CL*)GLB4$%2.CI$:7-T.CHD8VUD(GTH)%\I
M(&9O<B!`05)'5CL*97AI=#L*?0I]"G5N<VAI9G0@0$E.0RP@0&%D9%]T;U]I
M;F,["GT*?0II9B`H)&]U="D@>PI["G)E<75I<F4@24\Z.D9I;&4["G)E<75I
M<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E($1I9V5S=#HZ4TA!.PI]"FUY("1P
M87(@/2!S:&EF="A`05)'5BD["FUY("1Z:7`["FEF("AD969I;F5D("1P87(I
M('L*;W!E;B!M>2`D9F@L("<\)RP@)'!A<B!O<B!D:64@(D-A;FYO="!F:6YD
M("<D<&%R)SH@)"$B.PIB:6YM;V1E*"1F:"D["F)L97-S*"1F:"P@)TE/.CI&
M:6QE)RD["B1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL**"`D>FEP+3YR96%D
M1G)O;49I;&5(86YD;&4H)&9H+"`D<&%R*2`]/2!!<F-H:79E.CI::7`Z.D%:
M7T]+*"D@*0IO<B!D:64@(E)E860@)R1P87(G(&5R<F]R.B`D(2(["GT*;7D@
M)65N=B`](&1O('L*:68@*"1Z:7`@86YD(&UY("1M971A(#T@)'II<"T^8V]N
M=&5N=',H)TU%5$$N>6UL)RDI('L*)&UE=&$@/7X@<R\N*EYP87(Z)"\O;7,[
M"B1M971A(#U^(',O7EQ3+BHO+VUS.PHD;65T82`]?B`O7B`@*%M>.ETK*3H@
M*"XK*20O;6<["GT*?3L*;&]C86P@)"\@/2!<-#L*:68@*&1E9FEN960@)'!A
M<BD@>PIO<&5N(%!!4BP@)SPG+"`D<&%R(&]R(&1I92`B)"$Z("1P87(B.PIB
M:6YM;V1E*%!!4BD["F1I92`B)'!A<B!I<R!N;W0@82!005(@9FEL92(@=6YL
M97-S(#Q005(^(&5Q(")02UPP,#-<,#`T(CL*?0I#<F5A=&50871H*"1O=70I
M(#L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=R@*)&]U="P*24\Z.D9I;&4Z.D]?
M0U)%050H*2!\($E/.CI&:6QE.CI/7U=23TY,62@I('P@24\Z.D9I;&4Z.D]?
M5%)53D,H*2P*,#<W-RP**2!O<B!D:64@)"$["F)I;FUO9&4H)&9H*3L*)"\@
M/2`H9&5F:6YE9"`D9&%T85]P;W,I(#\@7"1D871A7W!O<R`Z('5N9&5F.PIS
M965K(%]&2"P@,"P@,#L*;7D@)&QO861E<B`]('-C86QA<B`\7T9(/CL*:68@
M*"$D14Y6>U!!4E]615)"051)37T@86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<
M0')E;2DO*2!["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PI005(Z
M.D9I;'1E<CHZ4&]D4W1R:7`M/FYE=RT^87!P;'DH7"1L;V%D97(L("0P*0I]
M"F9O<F5A8V@@;7D@)&ME>2`H<V]R="!K97ES("5E;G8I('L*;7D@)'9A;"`]
M("1E;G9[)&ME>7T@;W(@;F5X=#L*)'9A;"`](&5V86P@)'9A;"!I9B`D=F%L
M(#U^("]>6R<B72\["FUY("1M86=I8R`](")?7T5.5E]005)?(B`N('5C*"1K
M97DI("X@(E]?(CL*;7D@)'-E="`](")005)?(B`N('5C*"1K97DI("X@(CTD
M=F%L(CL*)&QO861E<B`]?B!S>R1M86=I8R@@*RE]>PHD;6%G:6,@+B`D<V5T
M("X@*"<@)R!X("AL96YG=&@H)#$I("T@;&5N9W1H*"1S970I*2D*?65G.PI]
M"B1F:"T^<')I;G0H)&QO861E<BD["B0O(#T@=6YD968["FEF("@D8G5N9&QE
M*2!["G)E<75I<F4@4$%2.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN
M86QO861E<B@I.PII;FET7VEN8R@I.PIR97%U:7)E7VUO9'5L97,H*3L*;7D@
M0&EN8R`](&=R97`@>R`A+T)31%!!3B\@?0IG<F5P('L**"1B=6YD;&4@;F4@
M)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E>'!]
M(&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF:6=[<')I=FQI8F5X<'TI.PI]($!)
M3D,["FUY("5F:6QE<SL*)&9I;&5S>R1??2LK(&9O<B!`1'EN84QO861E<CHZ
M9&Q?<VAA<F5D7V]B:F5C=',L('9A;'5E<R`E24Y#.PIM>2`D;&EB7V5X="`]
M("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT?3L*;7D@)7=R:71T96X["F9O<F5A
M8V@@*'-O<G0@:V5Y<R`E9FEL97,I('L*;7D@*"1N86UE+"`D9FEL92D["F9O
M<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PII9B`H)&YA;64@/2`D4$%2.CI(96%V
M>3HZ1G5L;$-A8VAE>R1??2D@>PHD9FEL92`]("1?.PIL87-T.PI]"F5L<VEF
M("@O7BA<421D:7)<15PO*"XJ6UY#8UTI*5Q:+VDI('L**"1F:6QE+"`D;F%M
M92D@/2`H)#$L("0R*3L*;&%S=#L*?0IE;'-I9B`H;2%>+VQO861E<B];7B]=
M*R\H+BI;7D-C72E<6B$I('L*:68@*&UY("1R968@/2`D4$%2.CI(96%V>3HZ
M36]D=6QE0V%C:&5[)#%]*2!["B@D9FEL92P@)&YA;64I(#T@*"1R968L("0Q
M*3L*;&%S=#L*?0IE;'-I9B`H+68@(B1D:7(O)#$B*2!["B@D9FEL92P@)&YA
M;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PIL87-T.PI]"GT*?0IN97AT('5N;&5S
M<R!D969I;F5D("1N86UE(&%N9"!N;W0@)'=R:71T96Y[)&YA;65]*RL["FYE
M>'0@:68@(7)E9B@D9FEL92D@86YD("1F:6QE(#U^("]<+EQ1)&QI8E]E>'1<
M120O.PIO=71S*"!J;VEN("(B+`IQ<2A086-K:6YG("(I+"!R968@)&9I;&4@
M/R`D9FEL92T^>VYA;65](#H@)&9I;&4L"G%Q*"(N+BXI"BD["FUY("1C;VYT
M96YT.PII9B`H<F5F*"1F:6QE*2D@>PHD8V]N=&5N="`]("1F:6QE+3Y[8G5F
M?3L*?0IE;'-E('L*;W!E;B!&24Q%+"`G/"<L("1F:6QE(&]R(&1I92`B0V%N
M)W0@;W!E;B`D9FEL93H@)"$B.PIB:6YM;V1E*$9)3$4I.PHD8V]N=&5N="`]
M(#Q&24Q%/CL*8VQO<V4@1DE,13L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YN
M97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4I"FEF("$D14Y6>U!!4E]615)"
M051)37T@86YD("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&
M:6QT97(Z.E!A=&-H0V]N=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F
M:6QE+"`D;F%M92D["GT*;W5T<RAQ<2A7<FET=&5N(&%S("(D;F%M92(I*3L*
M)&9H+3YP<FEN="@B1DE,12(I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG
M=&@H)&YA;64I("L@.2DI.PHD9F@M/G!R:6YT*'-P<FEN=&8H"B(E,#AX+R5S
M(BP@07)C:&EV93HZ6FEP.CIC;VUP=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M
M90HI*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@;&5N9W1H*"1C;VYT96YT*2DI
M.PHD9F@M/G!R:6YT*"1C;VYT96YT*3L*?0I]"B1Z:7`M/G=R:71E5&]&:6QE
M2&%N9&QE*"1F:"D@:68@)'II<#L*)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A
M8VAE7VYA;64L(#`L(#0P.PII9B`H(21C86-H95]N86UE(&%N9"!M>2`D;71I
M;64@/2`H<W1A="@D;W5T*2E;.5TI('L*;7D@)&-T>"`]($1I9V5S=#HZ4TA!
M+3YN97<H,2D["F]P96XH;7D@)&9H+"`B/"(L("1O=70I.PIB:6YM;V1E*"1F
M:"D["B1C='@M/F%D9&9I;&4H)&9H*3L*8VQO<V4H)&9H*3L*)&-A8VAE7VYA
M;64@/2`D8W1X+3YH97AD:6=E<W0["GT*)&-A8VAE7VYA;64@+CT@(EPP(B!X
M("@T,2`M(&QE;F=T:"`D8V%C:&5?;F%M92D["B1C86-H95]N86UE("X](")#
M04-(12(["B1F:"T^<')I;G0H)&-A8VAE7VYA;64I.PHD9F@M/G!R:6YT*'!A
M8VLH)TXG+"`D9F@M/G1E;&P@+2!L96YG=&@H)&QO861E<BDI*3L*)&9H+3YP
M<FEN="@D4$%27TU!1TE#*3L*)&9H+3YC;&]S93L*8VAM;V0@,#<U-2P@)&]U
M=#L*97AI=#L*?0I["FQA<W0@=6YL97-S(&1E9FEN960@)'-T87)T7W!O<SL*
M7V9I>%]P<F]G;F%M92@I.PIR97%U:7)E(%!!4CL*4$%2.CI(96%V>3HZ7VEN
M:71?9'EN86QO861E<B@I.PI["G)E<75I<F4@1FEL93HZ1FEN9#L*<F5Q=6ER
M92!!<F-H:79E.CI::7`["GT*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(",@07)C:&EV93HZ6FEP(&]P97)A
M=&5S(&]N(&%N($E/.CI(86YD;&4*)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL
M("=R)RD@;W(@9&EE("(D(3H@)$`B.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK
M4VEZ92@M<R!?1D@I.PIM>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B1Z
M:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M92D@/3T@07)C
M:&EV93HZ6FEP.CI!6E]/2R@I(&]R(&1I92`B)"$Z("1`(CL*07)C:&EV93HZ
M6FEP.CIS971#:'5N:U-I>F4H-C0@*B`Q,#(T*3L*<'5S:"!`4$%2.CI,:6)#
M86-H92P@)'II<#L*)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`[
M"B1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["F]U=',H<7$H7"1%3E9[4$%2
M7U1%35!](#T@(B1%3E9[4$%27U1%35!](BDI.PII9B`H9&5F:6YE9"`D14Y6
M>U!!4E]414U0?2D@>R`C('-H;W5L9"!B92!S970@870@=&AI<R!P;VEN="$*
M9F]R96%C:"!M>2`D;65M8F5R("@@)'II<"T^;65M8F5R<R`I('L*;F5X="!I
M9B`D;65M8F5R+3YI<T1I<F5C=&]R>3L*;7D@)&UE;6)E<E]N86UE(#T@)&UE
M;6)E<BT^9FEL94YA;64["FYE>'0@=6YL97-S("1M96UB97)?;F%M92`]?B!M
M>PI>"B\_<VAL:6(O"B@_.B1#;VYF:6<Z.D-O;F9I9WMV97)S:6]N?2\I/PHH
M/SHD0V]N9FEG.CI#;VYF:6=[87)C:&YA;65]+RD_"BA;7B]=*RD*)`I]>#L*
M;7D@)&5X=')A8W1?;F%M92`]("0Q.PIM>2`D9&5S=%]N86UE(#T@1FEL93HZ
M4W!E8RT^8V%T9FEL92@D14Y6>U!!4E]414U0?2P@)&5X=')A8W1?;F%M92D[
M"FEF("@M9B`D9&5S=%]N86UE("8F("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP
M<F5S<V5D4VEZ92@I*2!["F]U=',H<7$H4VMI<'!I;F<@(B1M96UB97)?;F%M
M92(@<VEN8V4@:70@86QR96%D>2!E>&ES=',@870@(B1D97-T7VYA;64B*2D[
M"GT@96QS92!["F]U=',H<7$H17AT<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T
M;R`B)&1E<W1?;F%M92(I*3L*)&UE;6)E<BT^97AT<F%C=%1O1FEL94YA;65D
M*"1D97-T7VYA;64I.PIC:&UO9"@P-34U+"`D9&5S=%]N86UE*2!I9B`D7D\@
M97$@(FAP=7@B.PI]"GT*?0I]"G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[)'!R
M;V=N86UE?2D@>PID:64@/#P@(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z("0P
M(%L@+4%L:6(N<&%R(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP
M87(@72!;('!R;V=R86TN<&P@70HD,"!;("U"?"UB(%T@6RU/;W5T9FEL95T@
M<W)C+G!A<@HN"B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M92`]("0P
M(#T@<VAI9G0H0$%21U8I.PI]"G-U8B!#<F5A=&50871H('L*;7D@*"1N86UE
M*2`]($!?.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIM>2`H)&)A<V5N86UE
M+"`D<&%T:"P@)&5X="D@/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E*"1N
M86UE+"`H)UPN+BHG*2D["G)E<75I<F4@1FEL93HZ4&%T:#L*1FEL93HZ4&%T
M:#HZ;6MP871H*"1P871H*2!U;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T:"!D
M:65S('=I=&@@97)R;W(*?0IS=6(@<F5Q=6ER95]M;V1U;&5S('L*<F5Q=6ER
M92!L:6(["G)E<75I<F4@1'EN84QO861E<CL*<F5Q=6ER92!I;G1E9V5R.PIR
M97%U:7)E('-T<FEC=#L*<F5Q=6ER92!W87)N:6YG<SL*<F5Q=6ER92!V87)S
M.PIR97%U:7)E($-A<G`["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@
M17)R;F\["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PIR97%U:7)E($5X<&]R
M=&5R.PIR97%U:7)E($9C;G1L.PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I
M<F4@1FEL93HZ4W!E8SL*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!#;VYF
M:6<["G)E<75I<F4@24\Z.DAA;F1L93L*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q
M=6ER92!#;VUP<F5S<SHZ6FQI8CL*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E
M<75I<F4@1&EG97-T.CI32$$["G)E<75I<F4@4$%2.PIR97%U:7)E(%!!4CHZ
M2&5A=GD["G)E<75I<F4@4$%2.CI$:7-T.PIR97%U:7)E(%!!4CHZ1FEL=&5R
M.CI0;V13=')I<#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT
M.PIR97%U:7)E(&%T=')I8G5T97,["F5V86P@>R!R97%U:7)E($-W9"!].PIE
M=F%L('L@<F5Q=6ER92!7:6XS,B!].PIE=F%L('L@<F5Q=6ER92!38V%L87(Z
M.E5T:6P@?3L*979A;"![(')E<75I<F4@07)C:&EV93HZ56YZ:7`Z.D)U<G-T
M('T["F5V86P@>R!R97%U:7)E(%1I93HZ2&%S:#HZ3F%M961#87!T=7)E('T[
M"F5V86P@>R!R97%U:7)E(%!E<FQ)3SL@<F5Q=6ER92!097)L24\Z.G-C86QA
M<B!].PIE=F%L('L@<F5Q=6ER92!U=&8X('T["GT*<W5B(%]S971?<&%R7W1E
M;7`@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?
M5$5-4'T@/7X@+R@N*RDO*2!["B1P87)?=&5M<"`]("0Q.PIR971U<FX["GT*
M9F]R96%C:"!M>2`D<&%T:"`H"BAM87`@)$5.5GLD7WTL('%W*"!005)?5$U0
M1$E2(%1-4$1)4B!414U01$E2(%1%35`@5$U0("DI+`IQ=R@@0SI<7%1%35`@
M+W1M<"`N("D**2!["FYE>'0@=6YL97-S(&1E9FEN960@)'!A=&@@86YD("UD
M("1P871H(&%N9"`M=R`D<&%T:#L*;7D@)'5S97)N86UE.PIM>2`D<'=U:60[
M"F5V86P@>R@D<'=U:60I(#T@9V5T<'=U:60H)#XI(&EF(&1E9FEN960@)#X[
M?3L*:68@*"!D969I;F5D*"97:6XS,CHZ3&]G:6Y.86UE*2`I('L*)'5S97)N
M86UE(#T@)E=I;C,R.CI,;V=I;DYA;64["GT*96QS:68@*&1E9FEN960@)'!W
M=6ED*2!["B1U<V5R;F%M92`]("1P=W5I9#L*?0IE;'-E('L*)'5S97)N86UE
M(#T@)$5.5GM54T523D%-17T@?'P@)$5.5GM54T52?2!\?"`G4UE35$5-)SL*
M?0HD=7-E<FYA;64@/7X@<R]<5R]?+V<["FUY("1S=&UP9&ER(#T@(B1P871H
M)$-O;F9I9WM?9&5L:6U]<&%R+2(N=6YP86-K*")(*B(L("1U<V5R;F%M92D[
M"FUK9&ER("1S=&UP9&ER+"`P-S4U.PII9B`H(21%3E9[4$%27T-,14%.?2!A
M;F0@;7D@)&UT:6UE(#T@*'-T870H)'!R;V=N86UE*2E;.5TI('L*;W!E;B`H
M;7D@)&9H+"`B/"(N("1P<F]G;F%M92D["G-E96L@)&9H+"`M,3@L(#(["G-Y
M<W)E860@)&9H+"!M>2`D8G5F+"`V.PII9B`H)&)U9B!E<2`B7#!#04-(12(I
M('L*<V5E:R`D9F@L("TU."P@,CL*<WES<F5A9"`D9F@L("1B=68L(#0Q.PHD
M8G5F(#U^(',O7#`O+V<["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC
M86-H92TB("X@)&)U9CL*?0IE;'-E('L*;7D@)&1I9V5S="`](&5V86P*>PIR
M97%U:7)E($1I9V5S=#HZ4TA!.PIM>2`D8W1X(#T@1&EG97-T.CI32$$M/FYE
M=R@Q*3L*;W!E;BAM>2`D9F@L("(\(BP@)'!R;V=N86UE*3L*8FEN;6]D92@D
M9F@I.PHD8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E*"1F:"D["B1C='@M/FAE
M>&1I9V5S=#L*?2`O+R`D;71I;64["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D
M96QI;7UC86-H92TD9&EG97-T(CL*?0IC;&]S92@D9F@I.PI]"F5L<V4@>PHD
M14Y6>U!!4E]#3$5!3GT@/2`Q.PHD<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L
M:6U]=&5M<"TD)"(["GT*)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*;6MD
M:7(@)'-T;7!D:7(L(#`W-34["FQA<W0["GT*)'!A<E]T96UP(#T@)#$@:68@
M)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+SL*
M?0IS=6(@7W1E;7!F:6QE('L*;7D@*"1N86UE+"`D8V]N=&5N=',L("1M;V1E
M*2`]($!?.PIM>2`D9G5L;&YA;64@/2`B)'!A<E]T96UP+R1N86UE(CL*=6YL
M97-S("@M92`D9G5L;&YA;64I('L*;7D@)'1E;7!N86UE(#T@(B1F=6QL;F%M
M92XD)"(["F]P96X@;7D@)&9H+"`G/B<L("1T96UP;F%M92!O<B!D:64@(F-A
M;B=T('=R:71E("1T96UP;F%M93H@)"$B.PIB:6YM;V1E("1F:#L*<')I;G0@
M)&9H("1C;VYT96YT<SL*8VQO<V4@)&9H.PIC:&UO9"`D;6]D92P@)'1E;7!N
M86UE(&EF(&1E9FEN960@)&UO9&4["G)E;F%M92@D=&5M<&YA;64L("1F=6QL
M;F%M92D@;W(@=6YL:6YK*"1T96UP;F%M92D["GT*<F5T=7)N("1F=6QL;F%M
M93L*?0IS=6(@7W-E=%]P<F]G;F%M92!["FEF("AD969I;F5D("1%3E9[4$%2
M7U!23T=.04U%?2!A;F0@)$5.5GM005)?4%)/1TY!345](#U^("\H+BLI+RD@
M>PHD<')O9VYA;64@/2`D,3L*?0HD<')O9VYA;64@?'P]("0P.PII9B`H)$5.
M5GM005)?5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM005)?5$5-
M4'TI(#X](#`I('L*)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN
M9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`K(#$I.PI]"FEF("@A
M)$5.5GM005)?4%)/1TY!345](&]R(&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I
M9WM?9&5L:6U]*2`^/2`P*2!["FEF("AO<&5N(&UY("1F:"P@)SPG+"`D<')O
M9VYA;64I('L*<F5T=7)N(&EF("US("1F:#L*?0II9B`H+7,@(B1P<F]G;F%M
M921#;VYF:6=[7V5X97TB*2!["B1P<F]G;F%M92`N/2`D0V]N9FEG>U]E>&5]
M.PIR971U<FX["GT*?0IF;W)E86-H(&UY("1D:7(@*'-P;&ET("]<421#;VYF
M:6=[<&%T:%]S97!]7$4O+"`D14Y6>U!!5$A]*2!["FYE>'0@:68@97AI<W1S
M("1%3E9[4$%27U1%35!](&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%35!].PHD
M9&ER(#U^(',O7%$D0V]N9FEG>U]D96QI;7U<120O+SL**"@D<')O9VYA;64@
M/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB
M*2P@;&%S="D*:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D
M0V]N9FEG>U]E>&5](CL**"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E
M;&EM?21P<F]G;F%M92(I+"!L87-T*0II9B`M<R`B)&1I<B1#;VYF:6=[7V1E
M;&EM?21P<F]G;F%M92(["GT*?0IS=6(@7V9I>%]P<F]G;F%M92!["B0P(#T@
M)'!R;V=N86UE('Q\/2`D14Y6>U!!4E]04D]'3D%-17T["FEF("AI;F1E>"@D
M<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/"`P*2!["B1P<F]G;F%M92`]
M("(N)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*?0IM>2`D<'=D(#T@*&1E
M9FEN960@)D-W9#HZ9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*.B`H*&1E9FEN
M960@)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I
M.PIC:&]M<"@D<'=D*3L*)'!R;V=N86UE(#U^(',O7B@_/5PN7"X_7%$D0V]N
M9FEG>U]D96QI;7U<12DO)'!W9"1#;VYF:6=[7V1E;&EM?2\["B1%3E9[4$%2
M7U!23T=.04U%?2`]("1P<F]G;F%M93L*?0IS=6(@7W!A<E]I;FET7V5N=B![
M"FEF("@@)$5.5GM005)?24Y)5$E!3$E:141]*RL@/3T@,2`I('L*<F5T=7)N
M.PI](&5L<V4@>PHD14Y6>U!!4E])3DE424%,25I%1'T@/2`R.PI]"F9O<B`H
M<7<H(%-005=.140@5$5-4"!#3$5!3B!$14)51R!#04-(12!04D]'3D%-12`I
M("D@>PID96QE=&4@)$5.5GLG4$%27R<N)%]].PI]"F9O<B`H<7<O(%1-4$1)
M4B!414U0($-,14%.($1%0E5'("\I('L*)$5.5GLG4$%27R<N)%]](#T@)$5.
M5GLG4$%27T=,3T)!3%\G+B1??2!I9B!E>&ES=',@)$5.5GLG4$%27T=,3T)!
M3%\G+B1??3L*?0IM>2`D<&%R7V-L96%N(#T@(E]?14Y67U!!4E]#3$5!3E]?
M("`@("`@("`@("`@("`@(CL*:68@*"1%3E9[4$%27U1%35!]*2!["F1E;&5T
M92`D14Y6>U!!4E]#3$5!3GT["GT*96QS:68@*"%E>&ES=',@)$5.5GM005)?
M1TQ/0D%,7T-,14%.?2D@>PIM>2`D=F%L=64@/2!S=6)S='(H)'!A<E]C;&5A
M;BP@,3(@*R!L96YG=&@H(D-,14%.(BDI.PHD14Y6>U!!4E]#3$5!3GT@/2`D
M,2!I9B`D=F%L=64@/7X@+UY005)?0TQ%04X]*%Q3*RDO.PI]"GT*<W5B(&]U
M=',@>PIR971U<FX@:68@)'%U:65T.PII9B`H)&QO9V9H*2!["G!R:6YT("1L
M;V=F:"`B0%]<;B(["GT*96QS92!["G!R:6YT(")`7UQN(CL*?0I]"G-U8B!I
M;FET7VEN8R!["G)E<75I<F4@0V]N9FEG.PIP=7-H($!)3D,L(&=R97`@9&5F
M:6YE9"P@;6%P("1#;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`IA<F-H;&EB97AP
M('!R:79L:6)E>'`@<VET96%R8VAE>'`@<VET96QI8F5X<`IV96YD;W)A<F-H
M97AP('9E;F1O<FQI8F5X<`HI.PI]"G!A8VMA9V4@;6%I;CL*<F5Q=6ER92!0
M05(["G5N<VAI9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R
M="A`<&%R7V%R9W,I.PID:64@<7$H<&%R+G!L.B!#86XG="!O<&5N('!E<FP@
M<V-R:7!T("(D<')O9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y
M7&XI"G5N;&5S<R`M92`D<')O9VYA;64["F1O("1P<F]G;F%M93L*0T]213HZ
M97AI="@D,2D@:68@*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE
M("1`(&EF("1`.PI].PHD.CI?7T524D]2(#T@)$`@:68@)$`["GT*0T]213HZ
M97AI="@D,2D@:68@*"0Z.E]?15)23U(@/7XO7E]42U]%6$E47UPH*%QD*RE<
M*2\I.PID:64@)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2.PHQ.PI?7T5.1%]?
M"@!P97)L>'-I+F,`7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@("``
M``$;`SOT````'0```/B3__\P!0``$);__PP!``!`EO__(`$``'R6__\T`0``
MY);__U@!```4E___>`$``-"7__^L`0``&)C__]`!``"HF/___`$``(B:__\X
M`@``V)O__W0"``!@G/__G`(``)B<__^\`@``[)S__^`"```<GO__%`,``"">
M__\H`P``\)___W0#```0H/__B`,``!2A___$`P``O*+___0#```4H___&`0`
M`#2C__\X!```Z*/__W`$``#$J?__P`0``!2M__\`!0``>*W__V`%``!(O___
MB`4``*2___^H!0``%,'__]P%````````$``````````!>E(`!'@>`1L,'P`0
M````&````/R4__\P`````````!`````L````&)7__SP`````````(````$``
M``!`E?__:`````!$#B"=!)X#0I,"4M[=TPX`````'````&0```"$E?__,```
M``!$#A"=`IX!1][=#@`````P````A````)25__^\`````$$.0)T(G@=$DP:4
M!94$E@.7`I@!8PK>W=?8U=;3U`X`00L`(````+@````<EO__2`````!!#C"=
M!IX%0I,$3M[=TPX`````*````-P```!`EO__D`````!!#D"=")X'0Y,&E`5$
ME026`UO>W=76T]0.```X````"`$``*26___@`0```$$.8)T,G@M"E0B6!T23
M"I0)0Y<&F`69!)H#`FW>W=G:U]C5UM/4#@`````X````1`$``$B8__]0`0``
M`$$.X`&=')X;0I48EA=%DQJ4&9<6F!69%)H3`DO>W=G:U]C5UM/4#@`````D
M````@`$``%R9__^(`````$$.L`&=%IX50I,4E!->WMW3U`X`````'````*@!
M``"\F?__.`````!!#A"=`IX!1M[=#@`````@````R`$``-29__]4`````$$.
M()T$G@-"DP)*WMW3#@`````P````[`$```2:__\P`0```$(.T$!!G8H(GHD(
M0I6&"):%"$.3B`B4AP@"0]W>U=;3U`X`$````"`"````F___!`````````!(
M````-`(``/":___0`0```$(.\"%!G9X$GIT$0I6:!):9!$*3G`24FP1&EY@$
MF)<$F98$FI4$FY0$`F;=WMO9VM?8U=;3U`X`````$````(`"``!TG/__(```
M```````X````E`(``("<__\$`0```$(.()T$G@-"DP)'WMW3#@!!#B"3`IT$
MG@-O"M[=TPX`00M"#@#3W=X````L````T`(``$B=__^H`0```$$.<)T.G@U"
MDPR4"T25"I8)0I<(`F#>W=?5UM/4#@`@``````,``,">__]8`````$$.()T$
MG@-"DP)0"M[=TPX`00L<````)`,``/2>__\@`````$$.$)T"G@%&WMT.````
M`#0```!$`P``])[__[0`````00XPG0:>!4*5`I8!0Y,$E`-,"M[=U=;3U`X`
M00M9WMW5UM/4#@``3````'P#``!PG___W`4```!"#I"#`D*=LB">L2!"EZP@
MF*L@0Y6N():M($63L""4KR"9JB":J2";J""<IR`#:`'=WMO<V=K7V-76T]0.
M```\````S`,``/RD__]0`P```$$.8)T,G@M"DPJ4"4*5")8'1)<&F`69!)H#
MFP*<`0+*WMW;W-G:U]C5UM/4#@``+`````P$```,J/__9`````!!#B"=!)X#
M0I,"E`%2"M[=T]0.`$$+0M[=T]0.````+````#P$``#`CO__U`$```!!#E"=
M"IX)0I,(E`=#E08":0K>W=73U`X`00L`````)````&P$```0J/__T!$```!!
M#K`%1)U6GE5#DU0#:P3=WM,.`````!P```"4!```N+G__UP`````00X0G0*>
M`57>W0X`````,````+0$``#TN?__<`$```!!#D"=")X'0I,&E`5&E026`Y<"
M?`K>W=?5UM/4#@!!"P```#````#H!```,+O__Y0!````00Y`G0B>!T*3!I0%
M0Y4$E@-"EP("5@K>W=?5UM/4#@!!"P``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#PA````````U"`````````!
M``````````$``````````0````````#9`@````````\`````````@00`````
M```,`````````#@:````````#0``````````30```````!D`````````@)L!
M```````;``````````@`````````&@````````"(FP$``````!P`````````
M"`````````#U_O]O`````"`"````````!0`````````0#0````````8`````
M````"`,````````*`````````)\$````````"P`````````8`````````!4`
M```````````````````#`````````'"=`0```````@````````#0!0``````
M`!0`````````!P`````````7`````````&@4````````!P````````"P$0``
M``````@`````````N`(````````)`````````!@`````````&```````````
M`````````/O__V\``````0``"`````#Y__]O`````!``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!0&@```````%`:````````4!H```````!0&@```````%`:````
M````4!H```````!0&@```````%`:````````4!H```````!0&@```````%`:
M````````4!H```````!0&@```````%`:````````4!H```````!0&@``````
M`%`:````````4!H```````!0&@```````%`:````````4!H```````!0&@``
M`````%`:````````4!H```````!0&@```````%`:````````4!H```````!0
M&@```````%`:````````4!H```````!0&@```````%`:````````4!H`````
M``!0&@```````%`:````````4!H```````!0&@```````%`:````````4!H`
M``````!0&@```````%`:````````4!H```````!0&@```````%`:````````
M4!H```````!0&@```````%`:````````4!H```````!0&@```````%`:````
M````4!H```````!0&@```````%`:````````4!H```````!0&@```````%`:
M````````4!H```````!0&@```````%`:````````4!H```````!0&@``````
M`%`:````````D)L!``````!0'@``````````````````````````````30``
M```````````````````````````X&@``````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````"@`0``````_____P`````030```````#M-````````````
M```````530```````!5.````````($T````````G3@```````"A-````````
M```````````L30```````#%-``````````````````#+3P```````$=#0SH@
M*$%L<&EN92`X+C,N,"D@."XS+C``1T-#.B`H06QP:6YE(#DN,BXP*2`Y+C(N
M,```+G-H<W1R=&%B`"YI;G1E<G``+F=N=2YH87-H`"YD>6YS>6T`+F1Y;G-T
M<@`N<F5L82YD>6X`+G)E;&$N<&QT`"YI;FET`"YT97AT`"YF:6YI`"YR;V1A
M=&$`+F5H7V9R86UE7VAD<@`N96A?9G)A;64`+FEN:71?87)R87D`+F9I;FE?
M87)R87D`+F1Y;F%M:6,`+F=O=``N9&%T80`N8G-S`"YC;VUM96YT````````
M````````````````````````````````````````````````````````````
M````````````````````````````"P````$````"```````````"````````
M``(````````:`````````````````````0```````````````````!,```#V
M__]O`@`````````@`@```````"`"````````Z``````````#``````````@`
M```````````````````=````"P````(`````````"`,````````(`P``````
M``@*````````!`````,````(`````````!@`````````)0````,````"````
M`````!`-````````$`T```````"?!````````````````````0``````````
M`````````"T````$`````@````````"P$0```````+`1````````N`(`````
M```#``````````@`````````&``````````W````!````$(`````````:!0`
M``````!H%````````-`%`````````P```!$````(`````````!@`````````
M00````$````&`````````#@:````````.!H````````0````````````````
M````!````````````````````#P````!````!@````````!0&@```````%`:
M``````````0``````````````````!``````````$`````````!'`````0``
M``8`````````4!X```````!0'@```````+`N```````````````````$````
M````````````````30````$````&``````````!-`````````$T````````0
M````````````````````!````````````````````%,````!`````@``````
M```030```````!!-````````2#T```````````````````$`````````````
M``````!;`````0````(`````````6(H```````!8B@```````/0`````````
M```````````$````````````````````:0````$````"`````````%"+````
M````4(L````````<!0``````````````````"````````````````````',`
M```.`````P````````"`FP$``````(";````````"```````````````````
M``@`````````"`````````!_````#P````,`````````B)L!``````"(FP``
M``````@````````````````````(``````````@`````````BP````8````#
M`````````)";`0``````D)L```````#@`0````````0`````````"```````
M```0`````````)0````!`````P````````!PG0$``````'"=````````D`(`
M``````````````````@`````````"`````````"9`````0````,`````````
M`*`!````````H````````'@````````````````````(````````````````
M````GP````@````#`````````'B@`0``````>*````````!8$```````````
M````````"````````````````````*0````!````,```````````````````
M`'B@````````-`````````````````````$``````````0`````````!````
M`P````````````````````````"LH````````*T````````````````````!
/````````````````````
